searchData={"items":[{"type":"module","title":"DiscordInteractions","doc":"Discord Interactions is a library for handling Discord slash commands and other interaction types in Elixir applications.","ref":"DiscordInteractions.html"},{"type":"module","title":"Configuration - DiscordInteractions","doc":"Add the library to your dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:discord_interactions, \"~> 0.1.0\"}\n  ]\nend\n```\n\nConfigure the library in your `config/runtime.exs` or `config/config.exs`:\n\n```elixir\nconfig :discord_interactions,\n  public_key: System.get_env(\"DISCORD_PUBLIC_KEY\"),\n  bot_token: System.get_env(\"DISCORD_BOT_TOKEN\"),\n  application_id: System.get_env(\"DISCORD_APPLICATION_ID\")\n```\n\nYou'll need to obtain these values from the Discord Developer Portal:\n- `DISCORD_PUBLIC_KEY`: Found in your application's \"General Information\" section\n- `DISCORD_BOT_TOKEN`: Found in your application's \"Bot\" section\n- `DISCORD_APPLICATION_ID`: Your application's ID found in the \"General Information\" section","ref":"DiscordInteractions.html#module-configuration"},{"type":"module","title":"Integration - DiscordInteractions","doc":"","ref":"DiscordInteractions.html#module-integration"},{"type":"module","title":"1. Create a Command Handler Module - DiscordInteractions","doc":"Create a module that will handle your Discord interactions:\n\n```elixir\ndefmodule YourApp.Discord do\n  use DiscordInteractions\n\n  # Define your interactions here\n  interactions do\n    # Commands will go here\n  end\n\n  # Command handler functions will go here\nend\n```","ref":"DiscordInteractions.html#module-1-create-a-command-handler-module"},{"type":"module","title":"2. Add the Plug to Your Router - DiscordInteractions","doc":"In your Phoenix router, add the Discord Interactions plug:\n\n```elixir\ndefmodule YourAppWeb.Router do\n  use YourAppWeb, :router\n\n  # Other pipelines and routes...\n\n  # Route for Discord interactions\n  forward \"/discord\", DiscordInteractions.Plug, YourApp.Discord\nend\n```","ref":"DiscordInteractions.html#module-2-add-the-plug-to-your-router"},{"type":"module","title":"3. Configure Your Endpoint - DiscordInteractions","doc":"The plug expects the raw request body to be available under `conn.assigns[:raw_body]` for signature verification. You can use the provided `CacheBodyReader` to achiveve this:\n\n```elixir\nplug Plug.Parsers,\n  parsers: [:urlencoded, :multipart, :json],\n  pass: [\"*/*\"],\n  json_decoder: Phoenix.json_library(),\n  body_reader: {DiscordInteractions.CacheBodyReader, :read_body, []}\n```","ref":"DiscordInteractions.html#module-3-configure-your-endpoint"},{"type":"module","title":"4. Add Command Registration to Your Application Supervisor - DiscordInteractions","doc":"The `DiscordInteractions.CommandRegistration` task registers the commands defined in your handler module with Discord. Add it to your application's supervision tree:\n\n```elixir\ndef start(_type, _args) do\n  children = [\n    # Other children...\n    YourAppWeb.Endpoint,\n    {DiscordInteractions.CommandRegistration, YourApp.Discord}\n  ]\n\n  opts = [strategy: :one_for_one, name: YourApp.Supervisor]\n  Supervisor.start_link(children, opts)\nend\n```","ref":"DiscordInteractions.html#module-4-add-command-registration-to-your-application-supervisor"},{"type":"module","title":"Implementing Command Handlers - DiscordInteractions","doc":"","ref":"DiscordInteractions.html#module-implementing-command-handlers"},{"type":"module","title":"Defining Commands - DiscordInteractions","doc":"Use the DSL to define your commands in the `interactions` block. The library provides macros for common command properties, but you can also use the `properties/1` macro to access any Discord API feature, even those not explicitly implemented in the library.\n\nYou can define both global commands (available in all servers where your bot is installed) and guild-specific commands (available only in specific servers). Guild commands are useful for testing, server-specific features, or commands that should only be available to certain communities. Guild commands update instantly, unlike global commands which can take up to an hour to propagate.\n\n```elixir\ninteractions do\n  # Simple command without options\n  application_command \"hello\" do\n    description(\"A friendly greeting command\")\n    handler(&hello_command/1)\n  end\n\n  # Command with options\n  application_command \"echo\" do\n    description(\"Repeats your message\")\n\n    # Add a required string option\n    option(\"message\", :string,\n      description: \"The message to echo back\",\n      required: true\n    )\n\n    handler(&echo_command/1)\n  end\n\n  # Command with multiple options of different types\n  application_command \"profile\" do\n    description(\"Set your profile information\")\n\n    option(\"name\", :string,\n      description: \"Your display name\",\n      required: true\n    )\n\n    option(\"age\", :integer,\n      description: \"Your age\",\n      min_value: 13,\n      max_value: 120\n    )\n\n    option(\"favorite_color\", :string,\n      description: \"Your favorite color\",\n      choices: [\n        %{name: \"Red\", value: \"red\"},\n        %{name: \"Green\", value: \"green\"},\n        %{name: \"Blue\", value: \"blue\"}\n      ]\n    )\n\n    handler(&profile_command/1)\n  end\n\n  # User context menu command (appears when right-clicking a user)\n  application_command \"View Profile\", :user do\n    # User commands don't need a description\n    handler(&view_profile_command/1)\n  end\n\n  # Message context menu command (appears when right-clicking a message)\n  application_command \"Translate\", :message do\n    # Message commands don't need a description\n    handler(&translate_message_command/1)\n  end\n\n  # Guild-specific command (only available in specific servers)\n  application_command \"test\" do\n    description(\"Test command for development\")\n    guild(\"123456789012345678\")  # Available in this guild\n    guild(\"876543210987654321\")  # And also in this guild\n    handler(&test_command/1)\n  end\n\n  # Handle component interactions (buttons, select menus)\n  message_component_handler(&handle_component/1)\n\n  # Handle modal submissions\n  modal_submit_handler(&handle_modal/1)\nend\n```","ref":"DiscordInteractions.html#module-defining-commands"},{"type":"module","title":"Implementing Handler Functions - DiscordInteractions","doc":"Handler functions receive the raw Discord interaction object and should return a response. The interaction object contains all the data sent by Discord, including command options, user information, and more.\n\nImplement the handler functions referenced in your command definitions using the `DiscordInteractions.InteractionResponse` module to create responses:\n\n```elixir\nalias DiscordInteractions.InteractionResponse\n\n# Simple command handler\ndef hello_command(interaction) do\n  # Access user information from the interaction\n  user = get_in(interaction, [\"member\", \"user\", \"username\"])\n\n  response = InteractionResponse.channel_message_with_source()\n             |> InteractionResponse.content(\"Hello, \" <> user)\n\n  {:ok, response}\nend\n\n# Command handler with a single option\ndef echo_command(interaction) do\n  # Extract option values from the interaction\n  options = get_in(interaction, [\"data\", \"options\"])\n\n  # Find the value of the \"message\" option\n  message = Enum.find_value(options, \"\", fn opt ->\n    if opt[\"name\"] == \"message\", do: opt[\"value\"], else: nil\n  end)\n\n  response = InteractionResponse.channel_message_with_source()\n             |> InteractionResponse.content(\"Echo: \" <> message)\n\n  {:ok, response}\nend\n\n# Command handler with multiple options\ndef profile_command(interaction) do\n  # Extract all options from the interaction\n  options = get_in(interaction, [\"data\", \"options\"])\n\n  # Extract each option value\n  name = Enum.find_value(options, \"\", fn opt ->\n    if opt[\"name\"] == \"name\", do: opt[\"value\"], else: nil\n  end)\n\n  # Integer options are returned as numbers\n  age = Enum.find_value(options, nil, fn opt ->\n    if opt[\"name\"] == \"age\", do: opt[\"value\"], else: nil\n  end)\n\n  # Options with choices return the value, not the name\n  favorite_color = Enum.find_value(options, nil, fn opt ->\n    if opt[\"name\"] == \"favorite_color\", do: opt[\"value\"], else: nil\n  end)\n\n  # Build a response with all the profile information\n  age_text = if age, do: Integer.to_string(age), else: \"not specified\"\n  color_text = if favorite_color, do: favorite_color, else: \"not specified\"\n\n  response = InteractionResponse.channel_message_with_source()\n             |> InteractionResponse.content(\"Profile set!\nName: \" <> name <>\n                                           \"\nAge: \" <> age_text <>\n                                           \"\nFavorite Color: \" <> color_text)\n\n  {:ok, response}\nend\n\n# User context menu command handler\ndef view_profile_command(interaction) do\n  # For user commands, the target user ID is in the data.target_id field\n  user_id = get_in(interaction, [\"data\", \"target_id\"])\n\n  # You can access information about the user who triggered the command\n  commander_name = get_in(interaction, [\"member\", \"user\", \"username\"])\n\n  # Create a response with information about the user\n  response = InteractionResponse.channel_message_with_source()\n             |> InteractionResponse.content(commander_name <> \" is viewing the profile of user ID: \" <> user_id <>\n                                           \"\n\nIn a real application, you would fetch and display user information here.\")\n\n  {:ok, response}\nend\n\n# Message context menu command handler\ndef translate_message_command(interaction) do\n  # For message commands, the target message ID is in the data.target_id field\n  message_id = get_in(interaction, [\"data\", \"target_id\"])\n\n  # In a real application, you would fetch the message content and translate it\n  # For this example, we'll just acknowledge that we received the command\n  response = InteractionResponse.channel_message_with_source()\n             |> InteractionResponse.content(\"Translating message ID: \" <> message_id <>\n                                           \"\n\nIn a real application, you would fetch the message content and translate it.\")\n\n  {:ok, response}\nend\n\n# Handler for a command available in multiple guilds\ndef test_command(interaction) do\n  # Get guild information\n  guild_id = get_in(interaction, [\"guild_id\"])\n  user = get_in(interaction, [\"member\", \"user\", \"username\"])\n\n  # Guild commands are useful for testing features before making them global\n  # They update instantly, unlike global commands which can take up to an hour\n  response = InteractionResponse.channel_message_with_source()\n             |> InteractionResponse.content(\"Test command executed by \" <> user <> \" in guild \" <> guild_id <> \"!\n\" <>\n                                           \"Guild commands are perfect for testing and server-specific features.\")\n\n  {:ok, response}\nend\n\n# Component handler with pattern matching on custom_id\ndef handle_component(%{\"data\" => %{\"custom_id\" => \"button_1\"}} = interaction) do\n  # Access user information from the interaction\n  user = get_in(interaction, [\"member\", \"user\", \"username\"])\n\n  response = InteractionResponse.channel_message_with_source()\n             |> InteractionResponse.content(user <> \" clicked button 1!\")\n\n  {:ok, response}\nend\n\ndef handle_component(%{\"data\" => %{\"custom_id\" => \"button_2\"}} = interaction) do\n  response = InteractionResponse.channel_message_with_source()\n             |> InteractionResponse.content(\"You clicked the danger button!\")\n\n  {:ok, response}\nend\n```","ref":"DiscordInteractions.html#module-implementing-handler-functions"},{"type":"module","title":"Response Types - DiscordInteractions","doc":"Handler functions should return one of:\n\n- `{:ok, response}` - Successful response with data.\n- `:ok` - Sends a `202 Accepted` response to the initial request. Use this if you want to send the interaction response manually using the Discord API. Note that the three second timeout still applies in this case.","ref":"DiscordInteractions.html#module-response-types"},{"type":"module","title":"Using Helper Modules for Responses - DiscordInteractions","doc":"The library provides helper modules to construct responses more easily. Use the `DiscordInteractions.InteractionResponse` module together with the `DiscordInteractions.Components` module:\n\n```elixir\nalias DiscordInteractions.InteractionResponse\nimport DiscordInteractions.Components\n\ndef button_command(_interaction) do\n  # Create action row with buttons\n  buttons_row = action_row(\n    components: [\n      button(\n        style: :primary,\n        label: \"Click Me\",\n        custom_id: \"button_1\"\n      ),\n      button(\n        style: :danger,\n        label: \"Danger\",\n        custom_id: \"button_2\"\n      )\n    ]\n  )\n\n  # Create the response with content and components\n  response = InteractionResponse.channel_message_with_source()\n             |> InteractionResponse.content(\"Here are some buttons:\")\n             |> InteractionResponse.components([buttons_row])\n\n  {:ok, response}\nend\n```","ref":"DiscordInteractions.html#module-using-helper-modules-for-responses"},{"type":"module","title":"Advanced Usage - DiscordInteractions","doc":"","ref":"DiscordInteractions.html#module-advanced-usage"},{"type":"module","title":"Command Options and Properties - DiscordInteractions","doc":"Command properties are raw Discord API structures that follow the [Discord API documentation](https://discord.com/developers/docs/interactions/application-commands). When using the `properties/1` macro, you're directly providing the JSON structure that Discord expects.\n\nThe `properties/1` macro is particularly useful for accessing Discord API features that aren't explicitly implemented in the library. You can use it to define any command option or property supported by Discord's API, even if there isn't a specific macro for it in this library.\n\nYou can define complex commands with options using the `option` macro:\n\n```elixir\napplication_command \"echo\" do\n  description(\"Repeats your message\")\n\n  # Add a required string option\n  option(\"message\", :string,\n    description: \"The message to echo back\",\n    required: true\n  )\n\n  handler(&echo_command/1)\nend\n```\n\nThe `option` macro supports all Discord option types:\n- `:sub_command` - A sub-command\n- `:sub_command_group` - A group of sub-commands\n- `:string` - A string value\n- `:integer` - An integer value\n- `:boolean` - A boolean value\n- `:user` - A Discord user\n- `:channel` - A Discord channel\n- `:role` - A Discord role\n- `:mentionable` - A mentionable entity (user, role, etc.)\n- `:number` - A floating-point number\n- `:attachment` - A file attachment\n\nYou can also use the raw `properties` macro for more complex scenarios:\n\n```elixir\napplication_command \"echo\" do\n  description(\"Repeats your message\")\n\n  # This is a raw Discord API structure following their documentation\n  properties(%{\n    type: 1,  # CHAT_INPUT\n    options: [\n      %{\n        type: 3,  # STRING\n        name: \"message\",\n        description: \"The message to echo back\",\n        required: true\n      }\n    ]\n  })\n\n  handler(&echo_command/1)\nend\n```\n\nWhen handling commands with options, you can access the options from the interaction data:\n\n```elixir\nalias DiscordInteractions.InteractionResponse\n\ndef echo_command(interaction) do\n  # Extract the option value from the interaction\n  options = interaction[\"data\"][\"options\"]\n  message = Enum.find_value(options, \"\", fn opt ->\n    if opt[\"name\"] == \"message\", do: opt[\"value\"], else: nil\n  end)\n\n  # Create response using the InteractionResponse module\n  response = InteractionResponse.channel_message_with_source()\n             |> InteractionResponse.content(\"Echo: \" <> message)\n\n  {:ok, response}\nend\n```","ref":"DiscordInteractions.html#module-command-options-and-properties"},{"type":"module","title":"Autocomplete Commands - DiscordInteractions","doc":"You can create commands with autocomplete options to provide dynamic suggestions as users type:\n\n```elixir\napplication_command \"search\" do\n  description(\"Search for items\")\n\n  # Define command option with autocomplete\n  option(\"query\", :string,\n    description: \"Search term\",\n    autocomplete: true\n  )\n\n  # Set the main command handler\n  handler(&search_command/1)\n\n  # Set the autocomplete handler for this command\n  autocomplete_handler(&search_autocomplete/1)\nend\n```\n\nImplement the autocomplete handler to provide suggestions as the user types:\n\n```elixir\nalias DiscordInteractions.InteractionResponse\n\ndef search_autocomplete(interaction) do\n  # Get the current input value\n  focused_option = Enum.find(\n    interaction[\"data\"][\"options\"],\n    fn opt -> opt[\"focused\"] == true end\n  )\n  current_input = focused_option[\"value\"]\n\n  # Generate suggestions based on the current input\n  suggestions =\n    case current_input do\n      \"a\" <> _ -> [\n        InteractionResponse.choice(\"Apple\", \"apple\"),\n        InteractionResponse.choice(\"Apricot\", \"apricot\"),\n        InteractionResponse.choice(\"Avocado\", \"avocado\")\n      ]\n      \"b\" <> _ -> [\n        InteractionResponse.choice(\"Banana\", \"banana\"),\n        InteractionResponse.choice(\"Blueberry\", \"blueberry\"),\n        InteractionResponse.choice(\"Blackberry\", \"blackberry\")\n      ]\n      _ -> [\n        InteractionResponse.choice(\"Apple\", \"apple\"),\n        InteractionResponse.choice(\"Banana\", \"banana\"),\n        InteractionResponse.choice(\"Cherry\", \"cherry\")\n      ]\n    end\n\n  # Return autocomplete suggestions\n  response = InteractionResponse.application_command_autocomplete_result(suggestions)\n  {:ok, response}\nend\n```","ref":"DiscordInteractions.html#module-autocomplete-commands"},{"type":"macro","title":"DiscordInteractions.application_command/4","doc":"Defines a Discord application command.\n\nThis macro creates a new application command with the given name and allows you to configure\nit using other macros within its block.","ref":"DiscordInteractions.html#application_command/4"},{"type":"macro","title":"Parameters - DiscordInteractions.application_command/4","doc":"- `name` - The name of the command (used as the command name in Discord)\n- `type` - The type of command (`:chat_input`, `:user`, or `:message`), defaults to `:chat_input`\n- `opts` - Additional options (reserved for future use)\n- `block` - A block containing command configuration","ref":"DiscordInteractions.html#application_command/4-parameters"},{"type":"macro","title":"Command Types - DiscordInteractions.application_command/4","doc":"- `:chat_input` - Slash commands that show up when a user types /\n- `:user` - Commands that appear in the context menu for users\n- `:message` - Commands that appear in the context menu for messages","ref":"DiscordInteractions.html#application_command/4-command-types"},{"type":"macro","title":"Example - DiscordInteractions.application_command/4","doc":"```elixir\n# Chat input command (slash command)\napplication_command \"hello\", :chat_input do\n  description(\"A friendly greeting command\")\n  handler(&hello_command/1)\nend\n\n# User context menu command\napplication_command \"Get User Info\", :user do\n  handler(&user_info_command/1)\nend\n\n# Message context menu command\napplication_command \"Translate\", :message do\n  handler(&translate_message_command/1)\nend\n\n# Guild-specific command\napplication_command \"admin\", :chat_input do\n  description(\"Admin-only command\")\n  guild(\"123456789012345678\")  # Specific to this guild\n  handler(&admin_command/1)\nend\n\n# Command with options (only valid for chat_input type)\napplication_command \"echo\", :chat_input do\n  description(\"Repeats your message\")\n\n  option(\"message\", :string,\n    description: \"The message to echo back\",\n    required: true\n  )\n\n  handler(&echo_command/1)\nend\n```\n\nNote: Description and options are only valid for `:chat_input` commands. User and message\ncommands don't support descriptions or options.","ref":"DiscordInteractions.html#application_command/4-example"},{"type":"macro","title":"DiscordInteractions.autocomplete_handler/1","doc":"Sets the autocomplete handler function for a command.\n\nThis handler will be called when a user is typing in an autocomplete option field.\nThe handler should return suggestions based on the current input.","ref":"DiscordInteractions.html#autocomplete_handler/1"},{"type":"macro","title":"Parameters - DiscordInteractions.autocomplete_handler/1","doc":"- `handler` - Function reference to handle autocomplete requests","ref":"DiscordInteractions.html#autocomplete_handler/1-parameters"},{"type":"macro","title":"Example - DiscordInteractions.autocomplete_handler/1","doc":"```elixir\napplication_command \"search\" do\n  description(\"Search for items\")\n\n  option(\"query\", :string,\n    description: \"Search term\",\n    autocomplete: true\n  )\n\n  handler(&search_command/1)\n  autocomplete_handler(&search_autocomplete/1)\nend\n\ndef search_autocomplete(interaction) do\n  # Get the current input value\n  focused_option = Enum.find(\n    interaction[\"data\"][\"options\"],\n    fn opt -> opt[\"focused\"] == true end\n  )\n  current_input = focused_option[\"value\"]\n\n  # Generate suggestions based on the current input\n  suggestions = [\n    InteractionResponse.choice(\"Option 1\", \"option1\"),\n    InteractionResponse.choice(\"Option 2\", \"option2\")\n  ]\n\n  # Return autocomplete suggestions\n  response = InteractionResponse.application_command_autocomplete_result(suggestions)\n  {:ok, response}\nend\n```","ref":"DiscordInteractions.html#autocomplete_handler/1-example"},{"type":"type","title":"DiscordInteractions.command/0","doc":"","ref":"DiscordInteractions.html#t:command/0"},{"type":"type","title":"DiscordInteractions.config/0","doc":"","ref":"DiscordInteractions.html#t:config/0"},{"type":"macro","title":"DiscordInteractions.description/1","doc":"Sets the description of a command.\n\nThis macro is used within an `application_command` block to set the command's description,\nwhich is displayed in the Discord UI.","ref":"DiscordInteractions.html#description/1"},{"type":"macro","title":"Parameters - DiscordInteractions.description/1","doc":"- `description` - The description text for the command","ref":"DiscordInteractions.html#description/1-parameters"},{"type":"macro","title":"Example - DiscordInteractions.description/1","doc":"```elixir\napplication_command \"hello\" do\n  description(\"A friendly greeting command\")\n  handler(&hello_command/1)\nend\n```","ref":"DiscordInteractions.html#description/1-example"},{"type":"type","title":"DiscordInteractions.guild/0","doc":"","ref":"DiscordInteractions.html#t:guild/0"},{"type":"macro","title":"DiscordInteractions.guild/1","doc":"Specifies that a command should be registered to a specific guild (server).\n\nBy default, commands are registered globally across all servers. This macro restricts\na command to only be available in the specified guild.","ref":"DiscordInteractions.html#guild/1"},{"type":"macro","title":"Parameters - DiscordInteractions.guild/1","doc":"- `guild` - The Discord guild (server) ID where the command should be available","ref":"DiscordInteractions.html#guild/1-parameters"},{"type":"macro","title":"Example - DiscordInteractions.guild/1","doc":"```elixir\napplication_command \"admin\" do\n  description(\"Admin-only command\")\n  guild(\"123456789012345678\")  # Specific to this guild\n  handler(&admin_command/1)\nend\n```\n\nYou can also make a command available in multiple guilds by calling this macro multiple times:\n\n```elixir\napplication_command \"test\" do\n  description(\"Test command\")\n  guild(\"123456789012345678\")  # Available in this guild\n  guild(\"876543210987654321\")  # And also in this guild\n  handler(&test_command/1)\nend\n```","ref":"DiscordInteractions.html#guild/1-example"},{"type":"macro","title":"DiscordInteractions.handler/1","doc":"Sets the handler function for a command.\n\nThis macro specifies which function should be called when a user invokes the command.\nThe handler function receives the interaction data and should return a response.","ref":"DiscordInteractions.html#handler/1"},{"type":"macro","title":"Parameters - DiscordInteractions.handler/1","doc":"- `handler` - Function reference to handle the command","ref":"DiscordInteractions.html#handler/1-parameters"},{"type":"macro","title":"Example - DiscordInteractions.handler/1","doc":"```elixir\napplication_command \"hello\" do\n  description(\"A friendly greeting command\")\n  handler(&hello_command/1)\nend\n\ndef hello_command(interaction) do\n  response = InteractionResponse.channel_message_with_source()\n             |> InteractionResponse.content(\"Hello, world!\")\n\n  {:ok, response}\nend\n```\n\nHandler functions should return one of:\n- `{:ok, response}` - Successful response with data\n- `:ok` - Success with no response data (202 Accepted)","ref":"DiscordInteractions.html#handler/1-example"},{"type":"macro","title":"DiscordInteractions.interactions/1","doc":"Defines a block for declaring Discord interactions.\n\nThis macro is the entry point for defining commands, handlers, and other interaction-related\nconfigurations. It should be used within a module that uses `DiscordInteractions`.","ref":"DiscordInteractions.html#interactions/1"},{"type":"macro","title":"Example - DiscordInteractions.interactions/1","doc":"```elixir\ndefmodule MyApp.Discord do\n  use DiscordInteractions\n\n  interactions do\n    # Define commands and handlers here\n\n    # Slash command (chat input)\n    application_command \"hello\", :chat_input do\n      description(\"A friendly greeting command\")\n      handler(&hello_command/1)\n    end\n\n    # User context menu command\n    application_command \"Get Avatar\", :user do\n      handler(&get_avatar_command/1)\n    end\n\n    # Message context menu command\n    application_command \"Translate\", :message do\n      handler(&translate_message_command/1)\n    end\n\n    message_component_handler(&handle_component/1)\n  end\n\n  # Implement handler functions here\n  def hello_command(_interaction) do\n    # ...\n  end\n\n  def get_avatar_command(_interaction) do\n    # ...\n  end\n\n  def translate_message_command(_interaction) do\n    # ...\n  end\nend\n```","ref":"DiscordInteractions.html#interactions/1-example"},{"type":"macro","title":"DiscordInteractions.message_component_handler/1","doc":"Sets the handler function for message component interactions.\n\nThis macro specifies which function should be called when a user interacts with\nmessage components like buttons or select menus.","ref":"DiscordInteractions.html#message_component_handler/1"},{"type":"macro","title":"Parameters - DiscordInteractions.message_component_handler/1","doc":"- `handler` - Function reference to handle component interactions","ref":"DiscordInteractions.html#message_component_handler/1-parameters"},{"type":"macro","title":"Example - DiscordInteractions.message_component_handler/1","doc":"```elixir\ninteractions do\n  # Define commands...\n\n  # Set the component handler\n  message_component_handler(&handle_component/1)\nend\n\n# Component handler with pattern matching on custom_id\ndef handle_component(%{\"data\" => %{\"custom_id\" => \"button_1\"}} = interaction) do\n  response = InteractionResponse.channel_message_with_source()\n             |> InteractionResponse.content(\"You clicked button 1!\")\n\n  {:ok, response}\nend\n\ndef handle_component(%{\"data\" => %{\"custom_id\" => \"button_2\"}} = interaction) do\n  response = InteractionResponse.channel_message_with_source()\n             |> InteractionResponse.content(\"You clicked button 2!\")\n\n  {:ok, response}\nend\n\n# Fallback for unhandled custom_ids\ndef handle_component(_interaction) do\n  :error\nend\n```","ref":"DiscordInteractions.html#message_component_handler/1-example"},{"type":"macro","title":"DiscordInteractions.modal_submit_handler/1","doc":"Sets the handler function for modal submissions.\n\nThis macro specifies which function should be called when a user submits a modal form.","ref":"DiscordInteractions.html#modal_submit_handler/1"},{"type":"macro","title":"Parameters - DiscordInteractions.modal_submit_handler/1","doc":"- `handler` - Function reference to handle modal submissions","ref":"DiscordInteractions.html#modal_submit_handler/1-parameters"},{"type":"macro","title":"Example - DiscordInteractions.modal_submit_handler/1","doc":"```elixir\ninteractions do\n  # Define commands...\n\n  # Set the modal submission handler\n  modal_submit_handler(&handle_modal/1)\nend\n\n# Modal handler with pattern matching on custom_id\ndef handle_modal(%{\"data\" => %{\"custom_id\" => \"feedback_form\"}} = interaction) do\n  # Extract values from the modal components\n  components = get_in(interaction, [\"data\", \"components\"])\n\n  feedback = Enum.find_value(components, \"\", fn component ->\n    text_inputs = component[\"components\"]\n\n    Enum.find_value(text_inputs, \"\", fn input ->\n      if input[\"custom_id\"] == \"feedback_input\", do: input[\"value\"], else: nil\n    end)\n  end)\n\n  # Create a response\n  response = InteractionResponse.channel_message_with_source()\n             |> InteractionResponse.content(\"Thank you for your feedback: #{feedback}\")\n\n  {:ok, response}\nend\n\n# Fallback for unhandled modal submissions\ndef handle_modal(_interaction) do\n  :error\nend\n```","ref":"DiscordInteractions.html#modal_submit_handler/1-example"},{"type":"macro","title":"DiscordInteractions.name/1","doc":"Sets the name of a command.\n\nThis macro is used within an `application_command` block to set or change the command's name.","ref":"DiscordInteractions.html#name/1"},{"type":"macro","title":"Parameters - DiscordInteractions.name/1","doc":"- `name` - The name of the command","ref":"DiscordInteractions.html#name/1-parameters"},{"type":"macro","title":"Example - DiscordInteractions.name/1","doc":"```elixir\napplication_command \"initial_name\" do\n  # Override the name\n  name(\"actual_name\")\n  description(\"A command with a different name\")\n  handler(&my_command/1)\nend\n```\n\nNote: In most cases, it's simpler to set the name directly in the `application_command` macro.","ref":"DiscordInteractions.html#name/1-example"},{"type":"macro","title":"DiscordInteractions.option/3","doc":"Adds an option to an application command.","ref":"DiscordInteractions.html#option/3"},{"type":"macro","title":"Parameters - DiscordInteractions.option/3","doc":"- `name` - The name of the option (used as the parameter name in Discord)\n- `type` - The type of the option (atom or integer)\n- `opts` - Additional option settings","ref":"DiscordInteractions.html#option/3-parameters"},{"type":"macro","title":"Option Types - DiscordInteractions.option/3","doc":"- `:sub_command` - A sub-command\n- `:sub_command_group` - A group of sub-commands\n- `:string` - A string value\n- `:integer` - An integer value\n- `:boolean` - A boolean value\n- `:user` - A Discord user\n- `:channel` - A Discord channel\n- `:role` - A Discord role\n- `:mentionable` - A mentionable entity (user, role, etc.)\n- `:number` - A floating-point number\n- `:attachment` - A file attachment","ref":"DiscordInteractions.html#option/3-option-types"},{"type":"macro","title":"Additional Options - DiscordInteractions.option/3","doc":"- `:description` - Description of the option (default: \"\")\n- `:required` - Whether the option is required (default: false)\n- `:choices` - List of choices for the option\n- `:min_value` - Minimum value for integer/number options\n- `:max_value` - Maximum value for integer/number options\n- `:autocomplete` - Whether the option supports autocomplete (default: false)\n- `:channel_types` - List of channel types for channel options","ref":"DiscordInteractions.html#option/3-additional-options"},{"type":"macro","title":"Examples - DiscordInteractions.option/3","doc":"```elixir\n# Basic string option\noption(\"message\", :string, description: \"The message to echo back\", required: true)\n\n# Integer option with min/max values\noption(\"count\", :integer,\n  description: \"Number of times to repeat\",\n  min_value: 1,\n  max_value: 10,\n  required: false\n)\n\n# String option with choices\noption(\"color\", :string,\n  description: \"Choose a color\",\n  choices: [\n    %{name: \"Red\", value: \"red\"},\n    %{name: \"Green\", value: \"green\"},\n    %{name: \"Blue\", value: \"blue\"}\n  ]\n)\n\n# Channel option with specific channel types\noption(\"channel\", :channel,\n  description: \"Select a text channel\",\n  channel_types: [:guild_text, :guild_announcement]  # Text and announcement channels\n)\n\n# String option with autocomplete\noption(\"query\", :string,\n  description: \"Search term\",\n  autocomplete: true\n)\n```","ref":"DiscordInteractions.html#option/3-examples"},{"type":"macro","title":"DiscordInteractions.properties/1","doc":"Sets raw properties for a command.\n\nThis macro allows you to directly set properties on a command using the raw Discord API format.\nIt's useful for accessing Discord API features that aren't explicitly implemented in the library.","ref":"DiscordInteractions.html#properties/1"},{"type":"macro","title":"Parameters - DiscordInteractions.properties/1","doc":"- `properties` - A map of properties to merge with the command definition","ref":"DiscordInteractions.html#properties/1-parameters"},{"type":"macro","title":"Example - DiscordInteractions.properties/1","doc":"```elixir\napplication_command \"advanced\" do\n  description(\"An advanced command\")\n\n  # Set raw properties following Discord's API documentation\n  properties(%{\n    type: 1,  # CHAT_INPUT\n    default_member_permissions: \"8\",  # Administrator permission\n    dm_permission: false,  # Disable in DMs\n    nsfw: true  # Mark as NSFW\n  })\n\n  handler(&advanced_command/1)\nend\n```","ref":"DiscordInteractions.html#properties/1-example"},{"type":"module","title":"DiscordInteractions.API","doc":"Discord REST API client.","ref":"DiscordInteractions.API.html"},{"type":"type","title":"DiscordInteractions.API.application_id/0","doc":"","ref":"DiscordInteractions.API.html#t:application_id/0"},{"type":"function","title":"DiscordInteractions.API.batch_update_command_permissions/3","doc":"Batch updates permissions for multiple commands in a guild.","ref":"DiscordInteractions.API.html#batch_update_command_permissions/3"},{"type":"function","title":"Examples - DiscordInteractions.API.batch_update_command_permissions/3","doc":"iex> permissions = [\n    ...>   %{id: \"CMD_ID_1\", permissions: [%{id: \"ROLE_ID\", type: 1, permission: true}]},\n    ...>   %{id: \"CMD_ID_2\", permissions: [%{id: \"USER_ID\", type: 2, permission: true}]}\n    ...> ]\n    iex> {:ok, updated} = DiscordInteractions.Client.batch_update_command_permissions(client, \"GUILD_ID\", permissions)","ref":"DiscordInteractions.API.html#batch_update_command_permissions/3-examples"},{"type":"function","title":"DiscordInteractions.API.bulk_overwrite_global_commands/2","doc":"Bulk overwrites all global commands.","ref":"DiscordInteractions.API.html#bulk_overwrite_global_commands/2"},{"type":"function","title":"Examples - DiscordInteractions.API.bulk_overwrite_global_commands/2","doc":"iex> commands = [%{name: \"cmd1\", description: \"Command 1\"}, %{name: \"cmd2\", description: \"Command 2\"}]\n    iex> {:ok, updated} = DiscordInteractions.Client.bulk_overwrite_global_commands(client, commands)","ref":"DiscordInteractions.API.html#bulk_overwrite_global_commands/2-examples"},{"type":"function","title":"DiscordInteractions.API.bulk_overwrite_guild_commands/3","doc":"Bulk overwrites all commands in a guild.","ref":"DiscordInteractions.API.html#bulk_overwrite_guild_commands/3"},{"type":"function","title":"Examples - DiscordInteractions.API.bulk_overwrite_guild_commands/3","doc":"iex> commands = [%{name: \"cmd1\", description: \"Command 1\"}, %{name: \"cmd2\", description: \"Command 2\"}]\n    iex> {:ok, updated} = DiscordInteractions.Client.bulk_overwrite_guild_commands(client, \"GUILD_ID\", commands)","ref":"DiscordInteractions.API.html#bulk_overwrite_guild_commands/3-examples"},{"type":"type","title":"DiscordInteractions.API.client/0","doc":"","ref":"DiscordInteractions.API.html#t:client/0"},{"type":"type","title":"DiscordInteractions.API.command/0","doc":"","ref":"DiscordInteractions.API.html#t:command/0"},{"type":"type","title":"DiscordInteractions.API.command_id/0","doc":"","ref":"DiscordInteractions.API.html#t:command_id/0"},{"type":"type","title":"DiscordInteractions.API.commands/0","doc":"","ref":"DiscordInteractions.API.html#t:commands/0"},{"type":"function","title":"DiscordInteractions.API.create_followup_message/3","doc":"Creates a followup message for an interaction.","ref":"DiscordInteractions.API.html#create_followup_message/3"},{"type":"function","title":"Examples - DiscordInteractions.API.create_followup_message/3","doc":"iex> message = %{content: \"Followup message\"}\n    iex> {:ok, created} = DiscordInteractions.Client.create_followup_message(client, \"INTERACTION_TOKEN\", message)","ref":"DiscordInteractions.API.html#create_followup_message/3-examples"},{"type":"function","title":"DiscordInteractions.API.create_global_command/2","doc":"Creates a new global command.","ref":"DiscordInteractions.API.html#create_global_command/2"},{"type":"function","title":"Examples - DiscordInteractions.API.create_global_command/2","doc":"iex> command = %{name: \"test\", description: \"A test command\", type: 1}\n    iex> {:ok, created} = DiscordInteractions.Client.create_global_command(client, command)","ref":"DiscordInteractions.API.html#create_global_command/2-examples"},{"type":"function","title":"DiscordInteractions.API.create_guild_command/3","doc":"Creates a new command in a guild.","ref":"DiscordInteractions.API.html#create_guild_command/3"},{"type":"function","title":"Examples - DiscordInteractions.API.create_guild_command/3","doc":"iex> command = %{name: \"test\", description: \"A test command\", type: 1}\n    iex> {:ok, created} = DiscordInteractions.Client.create_guild_command(client, \"GUILD_ID\", command)","ref":"DiscordInteractions.API.html#create_guild_command/3-examples"},{"type":"function","title":"DiscordInteractions.API.create_interaction_response/4","doc":"Creates an initial response to an interaction.","ref":"DiscordInteractions.API.html#create_interaction_response/4"},{"type":"function","title":"Examples - DiscordInteractions.API.create_interaction_response/4","doc":"iex> response = %{type: 4, data: %{content: \"Hello!\"}}\n    iex> :ok = DiscordInteractions.Client.create_interaction_response(client, \"INTERACTION_ID\", \"INTERACTION_TOKEN\", response)","ref":"DiscordInteractions.API.html#create_interaction_response/4-examples"},{"type":"function","title":"DiscordInteractions.API.delete/3","doc":"Perform a DELETE request.\n\nSee `request/1` or `request/2` for options definition.\n\n    delete(\"/users\")\n    delete(\"/users\", query: [scope: \"admin\"])\n    delete(client, \"/users\")\n    delete(client, \"/users\", query: [scope: \"admin\"])\n    delete(client, \"/users\", body: %{name: \"Jon\"})","ref":"DiscordInteractions.API.html#delete/3"},{"type":"function","title":"DiscordInteractions.API.delete!/3","doc":"Perform a DELETE request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    delete!(\"/users\")\n    delete!(\"/users\", query: [scope: \"admin\"])\n    delete!(client, \"/users\")\n    delete!(client, \"/users\", query: [scope: \"admin\"])\n    delete!(client, \"/users\", body: %{name: \"Jon\"})","ref":"DiscordInteractions.API.html#delete!/3"},{"type":"function","title":"DiscordInteractions.API.delete_followup_message/3","doc":"Deletes a followup message for an interaction.","ref":"DiscordInteractions.API.html#delete_followup_message/3"},{"type":"function","title":"Examples - DiscordInteractions.API.delete_followup_message/3","doc":"iex> :ok = DiscordInteractions.Client.delete_followup_message(client, \"INTERACTION_TOKEN\", \"MESSAGE_ID\")","ref":"DiscordInteractions.API.html#delete_followup_message/3-examples"},{"type":"function","title":"DiscordInteractions.API.delete_global_command/2","doc":"Deletes a global command.","ref":"DiscordInteractions.API.html#delete_global_command/2"},{"type":"function","title":"Examples - DiscordInteractions.API.delete_global_command/2","doc":"iex> :ok = DiscordInteractions.Client.delete_global_command(client, \"CMD_ID\")","ref":"DiscordInteractions.API.html#delete_global_command/2-examples"},{"type":"function","title":"DiscordInteractions.API.delete_guild_command/3","doc":"Deletes a command from a guild.","ref":"DiscordInteractions.API.html#delete_guild_command/3"},{"type":"function","title":"Examples - DiscordInteractions.API.delete_guild_command/3","doc":"iex> :ok = DiscordInteractions.Client.delete_guild_command(client, \"GUILD_ID\", \"CMD_ID\")","ref":"DiscordInteractions.API.html#delete_guild_command/3-examples"},{"type":"function","title":"DiscordInteractions.API.delete_original_interaction_response/2","doc":"Deletes the initial response to an interaction.","ref":"DiscordInteractions.API.html#delete_original_interaction_response/2"},{"type":"function","title":"Examples - DiscordInteractions.API.delete_original_interaction_response/2","doc":"iex> :ok = DiscordInteractions.Client.delete_original_interaction_response(client, \"INTERACTION_TOKEN\")","ref":"DiscordInteractions.API.html#delete_original_interaction_response/2-examples"},{"type":"function","title":"DiscordInteractions.API.edit_followup_message/4","doc":"Edits a followup message for an interaction.","ref":"DiscordInteractions.API.html#edit_followup_message/4"},{"type":"function","title":"Examples - DiscordInteractions.API.edit_followup_message/4","doc":"iex> message = %{content: \"Updated followup\"}\n    iex> {:ok, updated} = DiscordInteractions.Client.edit_followup_message(client, \"INTERACTION_TOKEN\", \"MESSAGE_ID\", message)","ref":"DiscordInteractions.API.html#edit_followup_message/4-examples"},{"type":"function","title":"DiscordInteractions.API.edit_original_interaction_response/3","doc":"Edits the initial response to an interaction.","ref":"DiscordInteractions.API.html#edit_original_interaction_response/3"},{"type":"function","title":"Examples - DiscordInteractions.API.edit_original_interaction_response/3","doc":"iex> message = %{content: \"Updated content\"}\n    iex> {:ok, updated} = DiscordInteractions.Client.edit_original_interaction_response(client, \"INTERACTION_TOKEN\", message)","ref":"DiscordInteractions.API.html#edit_original_interaction_response/3-examples"},{"type":"type","title":"DiscordInteractions.API.error/0","doc":"","ref":"DiscordInteractions.API.html#t:error/0"},{"type":"function","title":"DiscordInteractions.API.get/3","doc":"Perform a GET request.\n\nSee `request/1` or `request/2` for options definition.\n\n    get(\"/users\")\n    get(\"/users\", query: [scope: \"admin\"])\n    get(client, \"/users\")\n    get(client, \"/users\", query: [scope: \"admin\"])\n    get(client, \"/users\", body: %{name: \"Jon\"})","ref":"DiscordInteractions.API.html#get/3"},{"type":"function","title":"DiscordInteractions.API.get!/3","doc":"Perform a GET request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    get!(\"/users\")\n    get!(\"/users\", query: [scope: \"admin\"])\n    get!(client, \"/users\")\n    get!(client, \"/users\", query: [scope: \"admin\"])\n    get!(client, \"/users\", body: %{name: \"Jon\"})","ref":"DiscordInteractions.API.html#get!/3"},{"type":"function","title":"DiscordInteractions.API.get_command_permissions/3","doc":"Gets permissions for a specific command in a guild.","ref":"DiscordInteractions.API.html#get_command_permissions/3"},{"type":"function","title":"Examples - DiscordInteractions.API.get_command_permissions/3","doc":"iex> {:ok, permissions} = DiscordInteractions.Client.get_command_permissions(client, \"GUILD_ID\", \"CMD_ID\")","ref":"DiscordInteractions.API.html#get_command_permissions/3-examples"},{"type":"function","title":"DiscordInteractions.API.get_followup_message/3","doc":"Gets a followup message for an interaction.","ref":"DiscordInteractions.API.html#get_followup_message/3"},{"type":"function","title":"Examples - DiscordInteractions.API.get_followup_message/3","doc":"iex> {:ok, message} = DiscordInteractions.Client.get_followup_message(client, \"INTERACTION_TOKEN\", \"MESSAGE_ID\")","ref":"DiscordInteractions.API.html#get_followup_message/3-examples"},{"type":"function","title":"DiscordInteractions.API.get_global_command/2","doc":"Gets a specific global command by ID.","ref":"DiscordInteractions.API.html#get_global_command/2"},{"type":"function","title":"Examples - DiscordInteractions.API.get_global_command/2","doc":"iex> {:ok, command} = DiscordInteractions.Client.get_global_command(client, \"CMD_ID\")","ref":"DiscordInteractions.API.html#get_global_command/2-examples"},{"type":"function","title":"DiscordInteractions.API.get_global_commands/1","doc":"Gets all global commands for the application.","ref":"DiscordInteractions.API.html#get_global_commands/1"},{"type":"function","title":"Examples - DiscordInteractions.API.get_global_commands/1","doc":"iex> {:ok, commands} = DiscordInteractions.Client.get_global_commands(client)","ref":"DiscordInteractions.API.html#get_global_commands/1-examples"},{"type":"function","title":"DiscordInteractions.API.get_guild_command/3","doc":"Gets a specific command in a guild.","ref":"DiscordInteractions.API.html#get_guild_command/3"},{"type":"function","title":"Examples - DiscordInteractions.API.get_guild_command/3","doc":"iex> {:ok, command} = DiscordInteractions.Client.get_guild_command(client, \"GUILD_ID\", \"CMD_ID\")","ref":"DiscordInteractions.API.html#get_guild_command/3-examples"},{"type":"function","title":"DiscordInteractions.API.get_guild_command_permissions/2","doc":"Gets permissions for all commands in a guild.","ref":"DiscordInteractions.API.html#get_guild_command_permissions/2"},{"type":"function","title":"Examples - DiscordInteractions.API.get_guild_command_permissions/2","doc":"iex> {:ok, permissions} = DiscordInteractions.Client.get_guild_command_permissions(client, \"GUILD_ID\")","ref":"DiscordInteractions.API.html#get_guild_command_permissions/2-examples"},{"type":"function","title":"DiscordInteractions.API.get_guild_commands/2","doc":"Gets all commands for a specific guild.","ref":"DiscordInteractions.API.html#get_guild_commands/2"},{"type":"function","title":"Examples - DiscordInteractions.API.get_guild_commands/2","doc":"iex> {:ok, commands} = DiscordInteractions.Client.get_guild_commands(client, \"GUILD_ID\")","ref":"DiscordInteractions.API.html#get_guild_commands/2-examples"},{"type":"function","title":"DiscordInteractions.API.get_original_interaction_response/2","doc":"Gets the initial response to an interaction.","ref":"DiscordInteractions.API.html#get_original_interaction_response/2"},{"type":"function","title":"Examples - DiscordInteractions.API.get_original_interaction_response/2","doc":"iex> {:ok, message} = DiscordInteractions.Client.get_original_interaction_response(client, \"INTERACTION_TOKEN\")","ref":"DiscordInteractions.API.html#get_original_interaction_response/2-examples"},{"type":"type","title":"DiscordInteractions.API.guild_id/0","doc":"","ref":"DiscordInteractions.API.html#t:guild_id/0"},{"type":"function","title":"DiscordInteractions.API.head/3","doc":"Perform a HEAD request.\n\nSee `request/1` or `request/2` for options definition.\n\n    head(\"/users\")\n    head(\"/users\", query: [scope: \"admin\"])\n    head(client, \"/users\")\n    head(client, \"/users\", query: [scope: \"admin\"])\n    head(client, \"/users\", body: %{name: \"Jon\"})","ref":"DiscordInteractions.API.html#head/3"},{"type":"function","title":"DiscordInteractions.API.head!/3","doc":"Perform a HEAD request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    head!(\"/users\")\n    head!(\"/users\", query: [scope: \"admin\"])\n    head!(client, \"/users\")\n    head!(client, \"/users\", query: [scope: \"admin\"])\n    head!(client, \"/users\", body: %{name: \"Jon\"})","ref":"DiscordInteractions.API.html#head!/3"},{"type":"type","title":"DiscordInteractions.API.interaction_callback_response/0","doc":"","ref":"DiscordInteractions.API.html#t:interaction_callback_response/0"},{"type":"type","title":"DiscordInteractions.API.interaction_id/0","doc":"","ref":"DiscordInteractions.API.html#t:interaction_id/0"},{"type":"type","title":"DiscordInteractions.API.interaction_response/0","doc":"","ref":"DiscordInteractions.API.html#t:interaction_response/0"},{"type":"type","title":"DiscordInteractions.API.interaction_token/0","doc":"","ref":"DiscordInteractions.API.html#t:interaction_token/0"},{"type":"type","title":"DiscordInteractions.API.message/0","doc":"","ref":"DiscordInteractions.API.html#t:message/0"},{"type":"type","title":"DiscordInteractions.API.message_id/0","doc":"","ref":"DiscordInteractions.API.html#t:message_id/0"},{"type":"function","title":"DiscordInteractions.API.new/1","doc":"Creates a new API client with the given token.","ref":"DiscordInteractions.API.html#new/1"},{"type":"function","title":"Examples - DiscordInteractions.API.new/1","doc":"iex> client = DiscordInteractions.Client.new(application_id: \"APP_ID\", token: \"BOT_TOKEN\")","ref":"DiscordInteractions.API.html#new/1-examples"},{"type":"type","title":"DiscordInteractions.API.option/0","doc":"Options that may be passed to a request function. See `request/2` for detailed descriptions.","ref":"DiscordInteractions.API.html#t:option/0"},{"type":"function","title":"DiscordInteractions.API.options/3","doc":"Perform a OPTIONS request.\n\nSee `request/1` or `request/2` for options definition.\n\n    options(\"/users\")\n    options(\"/users\", query: [scope: \"admin\"])\n    options(client, \"/users\")\n    options(client, \"/users\", query: [scope: \"admin\"])\n    options(client, \"/users\", body: %{name: \"Jon\"})","ref":"DiscordInteractions.API.html#options/3"},{"type":"function","title":"DiscordInteractions.API.options!/3","doc":"Perform a OPTIONS request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    options!(\"/users\")\n    options!(\"/users\", query: [scope: \"admin\"])\n    options!(client, \"/users\")\n    options!(client, \"/users\", query: [scope: \"admin\"])\n    options!(client, \"/users\", body: %{name: \"Jon\"})","ref":"DiscordInteractions.API.html#options!/3"},{"type":"function","title":"DiscordInteractions.API.patch/4","doc":"Perform a PATCH request.\n\nSee `request/1` or `request/2` for options definition.\n\n    patch(\"/users\", %{name: \"Jon\"})\n    patch(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    patch(client, \"/users\", %{name: \"Jon\"})\n    patch(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"DiscordInteractions.API.html#patch/4"},{"type":"function","title":"DiscordInteractions.API.patch!/4","doc":"Perform a PATCH request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    patch!(\"/users\", %{name: \"Jon\"})\n    patch!(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    patch!(client, \"/users\", %{name: \"Jon\"})\n    patch!(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"DiscordInteractions.API.html#patch!/4"},{"type":"type","title":"DiscordInteractions.API.permissions/0","doc":"","ref":"DiscordInteractions.API.html#t:permissions/0"},{"type":"function","title":"DiscordInteractions.API.post/4","doc":"Perform a POST request.\n\nSee `request/1` or `request/2` for options definition.\n\n    post(\"/users\", %{name: \"Jon\"})\n    post(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    post(client, \"/users\", %{name: \"Jon\"})\n    post(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"DiscordInteractions.API.html#post/4"},{"type":"function","title":"DiscordInteractions.API.post!/4","doc":"Perform a POST request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    post!(\"/users\", %{name: \"Jon\"})\n    post!(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    post!(client, \"/users\", %{name: \"Jon\"})\n    post!(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"DiscordInteractions.API.html#post!/4"},{"type":"function","title":"DiscordInteractions.API.put/4","doc":"Perform a PUT request.\n\nSee `request/1` or `request/2` for options definition.\n\n    put(\"/users\", %{name: \"Jon\"})\n    put(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    put(client, \"/users\", %{name: \"Jon\"})\n    put(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"DiscordInteractions.API.html#put/4"},{"type":"function","title":"DiscordInteractions.API.put!/4","doc":"Perform a PUT request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    put!(\"/users\", %{name: \"Jon\"})\n    put!(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    put!(client, \"/users\", %{name: \"Jon\"})\n    put!(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"DiscordInteractions.API.html#put!/4"},{"type":"function","title":"DiscordInteractions.API.request/2","doc":"Perform a request.","ref":"DiscordInteractions.API.html#request/2"},{"type":"function","title":"Options - DiscordInteractions.API.request/2","doc":"- `:method` - the request method, one of [`:head`, `:get`, `:delete`, `:trace`, `:options`, `:post`, `:put`, `:patch`]\n- `:url` - either full url e.g. \"http://example.com/some/path\" or just \"/some/path\" if using `Tesla.Middleware.BaseUrl`\n- `:query` - a keyword list of query params, e.g. `[page: 1, per_page: 100]`\n- `:headers` - a keyword list of headers, e.g. `[{\"content-type\", \"text/plain\"}]`\n- `:body` - depends on used middleware:\n    - by default it can be a binary\n    - if using e.g. JSON encoding middleware it can be a nested map\n    - if adapter supports it it can be a Stream with any of the above\n- `:opts` - custom, per-request middleware or adapter options","ref":"DiscordInteractions.API.html#request/2-options"},{"type":"function","title":"Examples - DiscordInteractions.API.request/2","doc":"ExampleApi.request(method: :get, url: \"/users/path\")\n\n    # use shortcut methods\n    ExampleApi.get(\"/users/1\")\n    ExampleApi.post(client, \"/users\", %{name: \"Jon\"})","ref":"DiscordInteractions.API.html#request/2-examples"},{"type":"function","title":"DiscordInteractions.API.request!/2","doc":"Perform request and raise in case of error.\n\nThis is similar to `request/2` behaviour from Tesla 0.x\n\nSee `request/2` for list of available options.","ref":"DiscordInteractions.API.html#request!/2"},{"type":"function","title":"DiscordInteractions.API.trace/3","doc":"Perform a TRACE request.\n\nSee `request/1` or `request/2` for options definition.\n\n    trace(\"/users\")\n    trace(\"/users\", query: [scope: \"admin\"])\n    trace(client, \"/users\")\n    trace(client, \"/users\", query: [scope: \"admin\"])\n    trace(client, \"/users\", body: %{name: \"Jon\"})","ref":"DiscordInteractions.API.html#trace/3"},{"type":"function","title":"DiscordInteractions.API.trace!/3","doc":"Perform a TRACE request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    trace!(\"/users\")\n    trace!(\"/users\", query: [scope: \"admin\"])\n    trace!(client, \"/users\")\n    trace!(client, \"/users\", query: [scope: \"admin\"])\n    trace!(client, \"/users\", body: %{name: \"Jon\"})","ref":"DiscordInteractions.API.html#trace!/3"},{"type":"function","title":"DiscordInteractions.API.update_command_permissions/4","doc":"Updates permissions for a specific command in a guild.","ref":"DiscordInteractions.API.html#update_command_permissions/4"},{"type":"function","title":"Examples - DiscordInteractions.API.update_command_permissions/4","doc":"iex> permissions = %{permissions: [%{id: \"ROLE_ID\", type: 1, permission: true}]}\n    iex> {:ok, updated} = DiscordInteractions.Client.update_command_permissions(client, \"GUILD_ID\", \"CMD_ID\", permissions)","ref":"DiscordInteractions.API.html#update_command_permissions/4-examples"},{"type":"function","title":"DiscordInteractions.API.update_global_command/3","doc":"Updates an existing global command.","ref":"DiscordInteractions.API.html#update_global_command/3"},{"type":"function","title":"Examples - DiscordInteractions.API.update_global_command/3","doc":"iex> command = %{name: \"test\", description: \"Updated description\", type: 1}\n    iex> {:ok, updated} = DiscordInteractions.Client.update_global_command(client, \"CMD_ID\", command)","ref":"DiscordInteractions.API.html#update_global_command/3-examples"},{"type":"function","title":"DiscordInteractions.API.update_guild_command/4","doc":"Updates an existing command in a guild.","ref":"DiscordInteractions.API.html#update_guild_command/4"},{"type":"function","title":"Examples - DiscordInteractions.API.update_guild_command/4","doc":"iex> command = %{name: \"test\", description: \"Updated description\", type: 1}\n    iex> {:ok, updated} = DiscordInteractions.Client.update_guild_command(client, \"GUILD_ID\", \"CMD_ID\", command)","ref":"DiscordInteractions.API.html#update_guild_command/4-examples"},{"type":"module","title":"DiscordInteractions.CacheBodyReader","doc":"A body reader implementation for `Plug.Parsers` that caches the raw request body for later use.\n\nThe `DiscordInteractions.Plug.ValidateRequest` plug uses the cached raw body to verify the request signature against Discord's security headers.","ref":"DiscordInteractions.CacheBodyReader.html"},{"type":"module","title":"Usage - DiscordInteractions.CacheBodyReader","doc":"Configure this body reader in your endpoint or router:\n\n```elixir\nplug Plug.Parsers,\n  parsers: [:urlencoded, :multipart, :json],\n  pass: [\"*/*\"],\n  json_decoder: Phoenix.json_library(),\n  body_reader: {DiscordInteractions.CacheBodyReader, :read_body, []}\n```","ref":"DiscordInteractions.CacheBodyReader.html#module-usage"},{"type":"function","title":"DiscordInteractions.CacheBodyReader.read_body/2","doc":"Reads and caches the request body.\n\nThis function wraps `Plug.Conn.read_body/2` and stores the retrieved body\nin `conn.assigns[:raw_body]` as a list of binary chunks.","ref":"DiscordInteractions.CacheBodyReader.html#read_body/2"},{"type":"behaviour","title":"DiscordInteractions.CommandHandler","doc":"Behaviour specification for Discord command handlers.","ref":"DiscordInteractions.CommandHandler.html"},{"type":"behaviour","title":"Return Values - DiscordInteractions.CommandHandler","doc":"The `handle/1` callback should return one of:\n\n- `{:ok, response}` - Successful response with data (200 OK)\n- `:ok` - Success with no response data (202 Accepted)\n- `:error` - Error handling the interaction (500 Internal Server Error)","ref":"DiscordInteractions.CommandHandler.html#module-return-values"},{"type":"callback","title":"DiscordInteractions.CommandHandler.handle/1","doc":"","ref":"DiscordInteractions.CommandHandler.html#c:handle/1"},{"type":"callback","title":"DiscordInteractions.CommandHandler.init/0","doc":"","ref":"DiscordInteractions.CommandHandler.html#c:init/0"},{"type":"module","title":"DiscordInteractions.CommandRegistration","doc":"This module is responsible for registering both global and guild-specific commands with Discord.","ref":"DiscordInteractions.CommandRegistration.html"},{"type":"module","title":"Usage - DiscordInteractions.CommandRegistration","doc":"Add the CommandRegistration task to your application's supervision tree:\n\n```elixir\ndef start(_type, _args) do\n  children = [\n    # Other children...\n    YourAppWeb.Endpoint,\n    {DiscordInteractions.CommandRegistration, YourApp.Discord}\n  ]\n\n  opts = [strategy: :one_for_one, name: YourApp.Supervisor]\n  Supervisor.start_link(children, opts)\nend\n```\n\nThe task will automatically register all commands defined in your handler module when your\napplication starts.","ref":"DiscordInteractions.CommandRegistration.html#module-usage"},{"type":"function","title":"DiscordInteractions.CommandRegistration.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\n`arg` is passed as the argument to `Task.start_link/1` in the `:start` field\nof the spec.\n\nFor more information, see the `Supervisor` module,\nthe `Supervisor.child_spec/2` function and the `t:Supervisor.child_spec/0` type.","ref":"DiscordInteractions.CommandRegistration.html#child_spec/1"},{"type":"function","title":"DiscordInteractions.CommandRegistration.register_all_guild_commands/1","doc":"","ref":"DiscordInteractions.CommandRegistration.html#register_all_guild_commands/1"},{"type":"function","title":"DiscordInteractions.CommandRegistration.register_commands/1","doc":"","ref":"DiscordInteractions.CommandRegistration.html#register_commands/1"},{"type":"function","title":"DiscordInteractions.CommandRegistration.register_global_commands/1","doc":"","ref":"DiscordInteractions.CommandRegistration.html#register_global_commands/1"},{"type":"function","title":"DiscordInteractions.CommandRegistration.register_guild_command/3","doc":"","ref":"DiscordInteractions.CommandRegistration.html#register_guild_command/3"},{"type":"function","title":"DiscordInteractions.CommandRegistration.start_link/1","doc":"","ref":"DiscordInteractions.CommandRegistration.html#start_link/1"},{"type":"module","title":"DiscordInteractions.Components","doc":"Helper module for creating Discord message components.\n\nThis module provides functions for creating various Discord message components\nas defined in the Discord API documentation:\nhttps://discord.com/developers/docs/components/reference","ref":"DiscordInteractions.Components.html"},{"type":"module","title":"Component Categories - DiscordInteractions.Components","doc":"","ref":"DiscordInteractions.Components.html#module-component-categories"},{"type":"module","title":"Layout Components - DiscordInteractions.Components","doc":"- Action Row (type 1): Container for other components\n- Section (type 9): Container for content components\n- Container (type 17): Container for sections","ref":"DiscordInteractions.Components.html#module-layout-components"},{"type":"module","title":"Interactive Components - DiscordInteractions.Components","doc":"- Button (type 2): Clickable button\n- String Select (type 3): Dropdown menu with options\n- Text Input (type 4): Text input field for modals\n- User Select (type 5): Select menu for users\n- Role Select (type 6): Select menu for roles\n- Mentionable Select (type 7): Select menu for mentionable entities\n- Channel Select (type 8): Select menu for channels","ref":"DiscordInteractions.Components.html#module-interactive-components"},{"type":"module","title":"Content Components - DiscordInteractions.Components","doc":"- Text Display (type 10): Text content\n- Thumbnail (type 11): Image thumbnail\n- Media Gallery (type 12): Gallery of media\n- File Component (type 13): File attachment\n- Separator (type 14): Visual separator","ref":"DiscordInteractions.Components.html#module-content-components"},{"type":"function","title":"DiscordInteractions.Components.action_row/1","doc":"Creates an action row component.\n\nAction rows are containers for other interactive components and are required\nfor buttons and select menus to be displayed in messages.","ref":"DiscordInteractions.Components.html#action_row/1"},{"type":"function","title":"Options - DiscordInteractions.Components.action_row/1","doc":"- `components` - List of components to include in the action row\n- `id` - Optional identifier for the action row","ref":"DiscordInteractions.Components.html#action_row/1-options"},{"type":"function","title":"Examples - DiscordInteractions.Components.action_row/1","doc":"# Create an action row with a button\n    DiscordInteractions.Components.action_row(\n      components: [\n        DiscordInteractions.Components.button(\n          style: :primary,\n          label: \"Click Me\",\n          custom_id: \"click_button\"\n        )\n      ]\n    )","ref":"DiscordInteractions.Components.html#action_row/1-examples"},{"type":"function","title":"DiscordInteractions.Components.button/1","doc":"Creates a button component.","ref":"DiscordInteractions.Components.html#button/1"},{"type":"function","title":"Options - DiscordInteractions.Components.button/1","doc":"- `style` - Button style (`:primary`, `:secondary`, `:success`, `:danger`, `:link`, `:premium`)\n- `label` - Button label text\n- `custom_id` - Custom identifier for the button (required for non-link buttons)\n- `url` - URL for link buttons (required for link buttons)\n- `emoji` - Emoji to display on the button (optional)\n- `disabled` - Whether the button is disabled (default: `false`)","ref":"DiscordInteractions.Components.html#button/1-options"},{"type":"function","title":"Examples - DiscordInteractions.Components.button/1","doc":"# Create a primary button\n    DiscordInteractions.Components.button(\n      style: :primary,\n      label: \"Click Me\",\n      custom_id: \"click_button\"\n    )\n\n    # Create a link button\n    DiscordInteractions.Components.button(\n      style: :link,\n      label: \"Visit Website\",\n      url: \"https://example.com\"\n    )\n\n    # Create a button with an emoji\n    DiscordInteractions.Components.button(\n      style: :success,\n      label: \"Confirm\",\n      custom_id: \"confirm_button\",\n      emoji: DiscordInteractions.Components.emoji(name: \"✅\")\n    )\n\n    # Create a premium button\n    DiscordInteractions.Components.button(\n      style: :premium,\n      label: \"Premium Feature\",\n      sku_id: \"123456789\"\n    )","ref":"DiscordInteractions.Components.html#button/1-examples"},{"type":"function","title":"DiscordInteractions.Components.channel_select/1","doc":"Creates a channel select menu component.","ref":"DiscordInteractions.Components.html#channel_select/1"},{"type":"function","title":"Options - DiscordInteractions.Components.channel_select/1","doc":"- `custom_id` - Custom identifier for the select menu\n- `placeholder` - Placeholder text when no option is selected (optional)\n- `min_values` - Minimum number of selected values (default: 1)\n- `max_values` - Maximum number of selected values (default: 1)\n- `channel_types` - List of channel types to include (optional)\n- `disabled` - Whether the select menu is disabled (default: `false`)","ref":"DiscordInteractions.Components.html#channel_select/1-options"},{"type":"function","title":"Examples - DiscordInteractions.Components.channel_select/1","doc":"# Create a channel select menu\n    DiscordInteractions.Components.channel_select(\n      custom_id: \"select_channel\",\n      placeholder: \"Select a channel\",\n      channel_types: [:guild_text, :guild_voice] # Text and voice channels\n    )","ref":"DiscordInteractions.Components.html#channel_select/1-examples"},{"type":"type","title":"DiscordInteractions.Components.component/0","doc":"","ref":"DiscordInteractions.Components.html#t:component/0"},{"type":"function","title":"DiscordInteractions.Components.container/1","doc":"Creates a container component.\n\nContainers are used to group sections together.","ref":"DiscordInteractions.Components.html#container/1"},{"type":"function","title":"Options - DiscordInteractions.Components.container/1","doc":"- `components` - List of section components to include in the container\n- `id` - Optional identifier for the container\n- `accent_color` - Optional accent color for the container (integer color value)\n- `spoiler` - Whether the container should be marked as a spoiler (default: `false`)","ref":"DiscordInteractions.Components.html#container/1-options"},{"type":"function","title":"Examples - DiscordInteractions.Components.container/1","doc":"# Create a container with a section\n    DiscordInteractions.Components.container(\n      components: [\n        DiscordInteractions.Components.section(\n          components: [\n            DiscordInteractions.Components.text_display(\n              content: \"This is some text content\"\n            )\n          ],\n          accessory: DiscordInteractions.Components.thumbnail(\n            media: \"https://example.com/image.png\"\n          )\n        )\n      ]\n    )\n\n    # Create a container with accent color as integer\n    DiscordInteractions.Components.container(\n      components: [\n        DiscordInteractions.Components.section(\n          components: [\n            DiscordInteractions.Components.text_display(\n              content: \"This is some text content\"\n            )\n          ],\n          accessory: DiscordInteractions.Components.thumbnail(\n            media: \"https://example.com/image.png\"\n          )\n        )\n      ],\n      accent_color: 0xFF0000\n    )\n\n    # Create a container with accent color as hex string\n    DiscordInteractions.Components.container(\n      components: [\n        DiscordInteractions.Components.section(\n          components: [\n            DiscordInteractions.Components.text_display(\n              content: \"This is some text content\"\n            )\n          ],\n          accessory: DiscordInteractions.Components.thumbnail(\n            media: \"https://example.com/image.png\"\n          )\n        )\n      ],\n      accent_color: \"#FF0000\"\n    )","ref":"DiscordInteractions.Components.html#container/1-examples"},{"type":"type","title":"DiscordInteractions.Components.emoji/0","doc":"","ref":"DiscordInteractions.Components.html#t:emoji/0"},{"type":"function","title":"DiscordInteractions.Components.emoji/1","doc":"Creates an emoji object for use in components like buttons.","ref":"DiscordInteractions.Components.html#emoji/1"},{"type":"function","title":"Options - DiscordInteractions.Components.emoji/1","doc":"- `name` - The name of the emoji (e.g., \"✅\")\n- `id` - The ID of a custom emoji (optional)\n- `animated` - Whether the emoji is animated (optional)","ref":"DiscordInteractions.Components.html#emoji/1-options"},{"type":"function","title":"Examples - DiscordInteractions.Components.emoji/1","doc":"# Create a simple emoji\n    DiscordInteractions.Components.emoji(name: \"✅\")\n\n    # Create a custom emoji with ID\n    DiscordInteractions.Components.emoji(name: \"custom_emoji\", id: \"123456789\", animated: true)","ref":"DiscordInteractions.Components.html#emoji/1-examples"},{"type":"function","title":"DiscordInteractions.Components.file/1","doc":"Creates a file component.","ref":"DiscordInteractions.Components.html#file/1"},{"type":"function","title":"Options - DiscordInteractions.Components.file/1","doc":"- `file` - File object with URL and filename\n- `id` - Optional identifier for the file component\n- `spoiler` - Whether the file should be marked as a spoiler (default: `false`)","ref":"DiscordInteractions.Components.html#file/1-options"},{"type":"function","title":"Examples - DiscordInteractions.Components.file/1","doc":"# Create a file component with URL\n    DiscordInteractions.Components.file(\n      file: \"https://example.com/document.pdf\"\n    )\n\n    # Create a file component with spoiler\n    DiscordInteractions.Components.file(\n      file: \"https://example.com/document.pdf\",\n      spoiler: true\n    )","ref":"DiscordInteractions.Components.html#file/1-examples"},{"type":"type","title":"DiscordInteractions.Components.media/0","doc":"","ref":"DiscordInteractions.Components.html#t:media/0"},{"type":"function","title":"DiscordInteractions.Components.media_gallery/1","doc":"Creates a media gallery component.","ref":"DiscordInteractions.Components.html#media_gallery/1"},{"type":"function","title":"Options - DiscordInteractions.Components.media_gallery/1","doc":"- `items` - List of media items to include in the gallery\n- `id` - Optional identifier for the media gallery","ref":"DiscordInteractions.Components.html#media_gallery/1-options"},{"type":"function","title":"Examples - DiscordInteractions.Components.media_gallery/1","doc":"# Create a media gallery with URLs\n    DiscordInteractions.Components.media_gallery(\n      items: [\n        \"https://example.com/image1.png\",\n        \"https://example.com/image2.png\"\n      ]\n    )\n\n    # Create a media gallery with ID\n    DiscordInteractions.Components.media_gallery(\n      id: \"my_gallery\",\n      items: [\n        \"https://example.com/image1.png\",\n        \"https://example.com/image2.png\"\n      ]\n    )","ref":"DiscordInteractions.Components.html#media_gallery/1-examples"},{"type":"function","title":"DiscordInteractions.Components.mentionable_select/1","doc":"Creates a mentionable select menu component.","ref":"DiscordInteractions.Components.html#mentionable_select/1"},{"type":"function","title":"Options - DiscordInteractions.Components.mentionable_select/1","doc":"- `custom_id` - Custom identifier for the select menu\n- `placeholder` - Placeholder text when no option is selected (optional)\n- `min_values` - Minimum number of selected values (default: 1)\n- `max_values` - Maximum number of selected values (default: 1)\n- `disabled` - Whether the select menu is disabled (default: `false`)","ref":"DiscordInteractions.Components.html#mentionable_select/1-options"},{"type":"function","title":"Examples - DiscordInteractions.Components.mentionable_select/1","doc":"# Create a mentionable select menu\n    DiscordInteractions.Components.mentionable_select(\n      custom_id: \"select_mentionable\",\n      placeholder: \"Select a user or role\",\n      min_values: 1,\n      max_values: 1\n    )\n\n    # Create a mentionable select menu with default values\n    DiscordInteractions.Components.mentionable_select(\n      custom_id: \"select_mentionable\",\n      placeholder: \"Select a user or role\",\n      default_values: [\n        %{id: \"123456789\", type: \"user\"},\n        %{id: \"987654321\", type: \"role\"}\n      ],\n      min_values: 1,\n      max_values: 5\n    )","ref":"DiscordInteractions.Components.html#mentionable_select/1-examples"},{"type":"function","title":"DiscordInteractions.Components.role_select/1","doc":"Creates a role select menu component.","ref":"DiscordInteractions.Components.html#role_select/1"},{"type":"function","title":"Options - DiscordInteractions.Components.role_select/1","doc":"- `custom_id` - Custom identifier for the select menu\n- `placeholder` - Placeholder text when no option is selected (optional)\n- `min_values` - Minimum number of selected values (default: 1)\n- `max_values` - Maximum number of selected values (default: 1)\n- `disabled` - Whether the select menu is disabled (default: `false`)","ref":"DiscordInteractions.Components.html#role_select/1-options"},{"type":"function","title":"Examples - DiscordInteractions.Components.role_select/1","doc":"# Create a role select menu\n    DiscordInteractions.Components.role_select(\n      custom_id: \"select_role\",\n      placeholder: \"Select a role\",\n      min_values: 1,\n      max_values: 1\n    )\n\n    # Create a role select menu with default values\n    DiscordInteractions.Components.role_select(\n      custom_id: \"select_role\",\n      placeholder: \"Select a role\",\n      default_values: [%{id: \"123456789\", type: \"role\"}],\n      min_values: 1,\n      max_values: 3\n    )","ref":"DiscordInteractions.Components.html#role_select/1-examples"},{"type":"function","title":"DiscordInteractions.Components.section/1","doc":"Creates a section component.\n\nSections are containers for content components like text, thumbnails, etc.","ref":"DiscordInteractions.Components.html#section/1"},{"type":"function","title":"Options - DiscordInteractions.Components.section/1","doc":"- `components` - List of content components to include in the section\n- `accessory` - Accessory component (e.g., thumbnail) to display alongside the section\n- `id` - Optional identifier for the section","ref":"DiscordInteractions.Components.html#section/1-options"},{"type":"function","title":"Examples - DiscordInteractions.Components.section/1","doc":"# Create a section with text display and thumbnail\n    DiscordInteractions.Components.section(\n      components: [\n        DiscordInteractions.Components.text_display(\n          content: \"This is some text content\"\n        )\n      ],\n      accessory: DiscordInteractions.Components.thumbnail(\n        media: \"https://example.com/image.png\"\n      )\n    )\n\n    # Create a section with ID\n    DiscordInteractions.Components.section(\n      id: \"intro_section\",\n      components: [\n        DiscordInteractions.Components.text_display(\n          content: \"This is some text content\"\n        )\n      ],\n      accessory: DiscordInteractions.Components.thumbnail(\n        media: \"https://example.com/image.png\",\n        description: \"Example image\"\n      )\n    )","ref":"DiscordInteractions.Components.html#section/1-examples"},{"type":"function","title":"DiscordInteractions.Components.select_option/1","doc":"Creates a select option for use in string select menus.","ref":"DiscordInteractions.Components.html#select_option/1"},{"type":"function","title":"Options - DiscordInteractions.Components.select_option/1","doc":"- `label` - The label for the option (displayed to users)\n- `value` - The value of the option (sent to your application)\n- `description` - Optional description for the option\n- `emoji` - Optional emoji to display with the option\n- `default` - Whether this option is selected by default (default: `false`)","ref":"DiscordInteractions.Components.html#select_option/1-options"},{"type":"function","title":"Examples - DiscordInteractions.Components.select_option/1","doc":"# Create a basic select option\n    DiscordInteractions.Components.select_option(\n      label: \"Option 1\",\n      value: \"opt1\"\n    )\n\n    # Create a select option with description and emoji\n    DiscordInteractions.Components.select_option(\n      label: \"Option 2\",\n      value: \"opt2\",\n      description: \"This is option 2\",\n      emoji: DiscordInteractions.Components.emoji(name: \"✅\"),\n      default: true\n    )","ref":"DiscordInteractions.Components.html#select_option/1-examples"},{"type":"function","title":"DiscordInteractions.Components.separator/1","doc":"Creates a separator component.","ref":"DiscordInteractions.Components.html#separator/1"},{"type":"function","title":"Options - DiscordInteractions.Components.separator/1","doc":"- `id` - Optional identifier for the separator\n- `divider` - Whether to show a divider line (default: `false`)\n- `spacing` - Spacing size (\"small\", \"medium\", \"large\")","ref":"DiscordInteractions.Components.html#separator/1-options"},{"type":"function","title":"Examples - DiscordInteractions.Components.separator/1","doc":"# Create a separator with a divider\n    DiscordInteractions.Components.separator(divider: true)\n\n    # Create a separator with medium spacing\n    DiscordInteractions.Components.separator(spacing: \"medium\")","ref":"DiscordInteractions.Components.html#separator/1-examples"},{"type":"function","title":"DiscordInteractions.Components.string_select/1","doc":"Creates a string select menu component.","ref":"DiscordInteractions.Components.html#string_select/1"},{"type":"function","title":"Options - DiscordInteractions.Components.string_select/1","doc":"- `custom_id` - Custom identifier for the select menu\n- `options` - List of options for the select menu\n- `placeholder` - Placeholder text when no option is selected (optional)\n- `min_values` - Minimum number of selected values (default: 1)\n- `max_values` - Maximum number of selected values (default: 1)\n- `disabled` - Whether the select menu is disabled (default: `false`)","ref":"DiscordInteractions.Components.html#string_select/1-options"},{"type":"function","title":"Examples - DiscordInteractions.Components.string_select/1","doc":"# Create a select menu with options\n    DiscordInteractions.Components.string_select(\n      custom_id: \"select_option\",\n      options: [\n        DiscordInteractions.Components.select_option(label: \"Option 1\", value: \"opt1\"),\n        DiscordInteractions.Components.select_option(label: \"Option 2\", value: \"opt2\")\n      ],\n      placeholder: \"Select an option\",\n      min_values: 1,\n      max_values: 1\n    )","ref":"DiscordInteractions.Components.html#string_select/1-examples"},{"type":"function","title":"DiscordInteractions.Components.text_display/1","doc":"Creates a text display component.","ref":"DiscordInteractions.Components.html#text_display/1"},{"type":"function","title":"Options - DiscordInteractions.Components.text_display/1","doc":"- `content` - Text content to display\n- `style` - Text style (`:normal`, `:heading`, `:subheading`, `:quote`, `:code_block`)\n- `format` - Text formatting (optional)","ref":"DiscordInteractions.Components.html#text_display/1-options"},{"type":"function","title":"Examples - DiscordInteractions.Components.text_display/1","doc":"# Create a normal text display\n    DiscordInteractions.Components.text_display(\n      content: \"This is some text content\"\n    )\n\n    # Create a heading text display\n    DiscordInteractions.Components.text_display(\n      content: \"This is a heading\",\n      style: :heading\n    )","ref":"DiscordInteractions.Components.html#text_display/1-examples"},{"type":"function","title":"DiscordInteractions.Components.text_input/1","doc":"Creates a text input component for modals.","ref":"DiscordInteractions.Components.html#text_input/1"},{"type":"function","title":"Options - DiscordInteractions.Components.text_input/1","doc":"- `custom_id` - Custom identifier for the text input\n- `style` - Text input style (`:short` or `:paragraph`)\n- `label` - Label for the text input\n- `min_length` - Minimum input length (optional)\n- `max_length` - Maximum input length (optional)\n- `required` - Whether the input is required (default: `true`)\n- `value` - Pre-filled value (optional)\n- `placeholder` - Placeholder text (optional)","ref":"DiscordInteractions.Components.html#text_input/1-options"},{"type":"function","title":"Examples - DiscordInteractions.Components.text_input/1","doc":"# Create a short text input\n    DiscordInteractions.Components.text_input(\n      custom_id: \"name_input\",\n      style: :short,\n      label: \"Name\",\n      placeholder: \"Enter your name\"\n    )\n\n    # Create a paragraph text input\n    DiscordInteractions.Components.text_input(\n      custom_id: \"feedback_input\",\n      style: :paragraph,\n      label: \"Feedback\",\n      min_length: 10,\n      max_length: 1000,\n      placeholder: \"Enter your feedback\"\n    )","ref":"DiscordInteractions.Components.html#text_input/1-examples"},{"type":"function","title":"DiscordInteractions.Components.thumbnail/1","doc":"Creates a thumbnail component.","ref":"DiscordInteractions.Components.html#thumbnail/1"},{"type":"function","title":"Options - DiscordInteractions.Components.thumbnail/1","doc":"- `media` - Media object with URL of the thumbnail image\n- `id` - Optional identifier for the thumbnail\n- `description` - Optional description for the thumbnail\n- `spoiler` - Whether the thumbnail should be marked as a spoiler (default: `false`)","ref":"DiscordInteractions.Components.html#thumbnail/1-options"},{"type":"function","title":"Examples - DiscordInteractions.Components.thumbnail/1","doc":"# Create a thumbnail with a URL\n    DiscordInteractions.Components.thumbnail(\n      media: \"https://example.com/image.png\"\n    )\n\n    # Create a thumbnail with description\n    DiscordInteractions.Components.thumbnail(\n      media: \"https://example.com/image.png\",\n      description: \"Example image\"\n    )\n\n    # Create a thumbnail with spoiler\n    DiscordInteractions.Components.thumbnail(\n      media: \"https://example.com/image.png\",\n      spoiler: true\n    )","ref":"DiscordInteractions.Components.html#thumbnail/1-examples"},{"type":"function","title":"DiscordInteractions.Components.user_select/1","doc":"Creates a user select menu component.","ref":"DiscordInteractions.Components.html#user_select/1"},{"type":"function","title":"Options - DiscordInteractions.Components.user_select/1","doc":"- `custom_id` - Custom identifier for the select menu\n- `placeholder` - Placeholder text when no option is selected (optional)\n- `min_values` - Minimum number of selected values (default: 1)\n- `max_values` - Maximum number of selected values (default: 1)\n- `disabled` - Whether the select menu is disabled (default: `false`)","ref":"DiscordInteractions.Components.html#user_select/1-options"},{"type":"function","title":"Examples - DiscordInteractions.Components.user_select/1","doc":"# Create a user select menu\n    DiscordInteractions.Components.user_select(\n      custom_id: \"select_user\",\n      placeholder: \"Select a user\",\n      min_values: 1,\n      max_values: 1\n    )\n\n    # Create a user select menu with default values\n    DiscordInteractions.Components.user_select(\n      custom_id: \"select_user\",\n      placeholder: \"Select a user\",\n      default_values: [%{id: \"123456789\", type: \"user\"}],\n      min_values: 1,\n      max_values: 3\n    )","ref":"DiscordInteractions.Components.html#user_select/1-examples"},{"type":"module","title":"DiscordInteractions.Embed","doc":"Helper module for creating Discord embed objects.\n\nThis module provides functions for creating and manipulating Discord embed objects\nas defined in the Discord API documentation:\nhttps://discord.com/developers/docs/resources/channel#embed-object\n\nEmbeds are rich content blocks that can contain formatted text, images, fields, and more.\nThey can be used in messages sent by bots and webhooks.","ref":"DiscordInteractions.Embed.html"},{"type":"module","title":"Embed Structure - DiscordInteractions.Embed","doc":"An embed object can have the following fields:\n- `title`: Title of the embed (up to 256 characters)\n- `description`: Description of the embed (up to 4096 characters)\n- `url`: URL for the embed title to link to\n- `timestamp`: ISO8601 timestamp for the embed footer\n- `color`: Color code of the embed (as an integer or hex string)\n- `footer`: Footer information (text, icon URL)\n- `image`: Image information (URL, dimensions)\n- `thumbnail`: Thumbnail information (URL, dimensions)\n- `video`: Video information (URL, dimensions)\n- `provider`: Provider information (name, URL)\n- `author`: Author information (name, URL, icon URL)\n- `fields`: Array of field objects (name, value, inline)","ref":"DiscordInteractions.Embed.html#module-embed-structure"},{"type":"module","title":"Examples - DiscordInteractions.Embed","doc":"# Create a basic embed\n    embed = DiscordInteractions.Embed.new()\n            |> DiscordInteractions.Embed.title(\"Hello, World!\")\n            |> DiscordInteractions.Embed.description(\"This is an embed description\")\n            |> DiscordInteractions.Embed.color(0x00FF00)\n\n    # Create an embed with fields\n    embed = DiscordInteractions.Embed.new()\n            |> DiscordInteractions.Embed.title(\"User Profile\")\n            |> DiscordInteractions.Embed.add_field(\"Name\", \"John Doe\", true)\n            |> DiscordInteractions.Embed.add_field(\"Age\", \"30\", true)\n            |> DiscordInteractions.Embed.add_field(\"Bio\", \"Lorem ipsum dolor sit amet\")\n\n    # Create an embed with author and footer\n    embed = DiscordInteractions.Embed.new()\n            |> DiscordInteractions.Embed.title(\"News Update\")\n            |> DiscordInteractions.Embed.description(\"Breaking news!\")\n            |> DiscordInteractions.Embed.author(\"News Bot\", \"https://example.com\", \"https://example.com/icon.png\")\n            |> DiscordInteractions.Embed.footer(\"Posted at 12:00 PM\", \"https://example.com/footer-icon.png\")","ref":"DiscordInteractions.Embed.html#module-examples"},{"type":"function","title":"DiscordInteractions.Embed.add_field/4","doc":"Adds a field to an embed.","ref":"DiscordInteractions.Embed.html#add_field/4"},{"type":"function","title":"Parameters - DiscordInteractions.Embed.add_field/4","doc":"- `embed`: The embed to modify\n- `name`: The name of the field (up to 256 characters)\n- `value`: The value of the field (up to 1024 characters)\n- `inline`: Whether the field should be displayed inline (default: false)","ref":"DiscordInteractions.Embed.html#add_field/4-parameters"},{"type":"function","title":"Examples - DiscordInteractions.Embed.add_field/4","doc":"iex> embed = DiscordInteractions.Embed.new()\n    iex> DiscordInteractions.Embed.add_field(embed, \"Name\", \"Value\")\n    %{fields: [%{name: \"Name\", value: \"Value\", inline: false}]}\n\n    iex> embed = DiscordInteractions.Embed.new()\n    iex> DiscordInteractions.Embed.add_field(embed, \"Name\", \"Value\", true)\n    %{fields: [%{name: \"Name\", value: \"Value\", inline: true}]}\n\n    iex> embed = DiscordInteractions.Embed.new() |> DiscordInteractions.Embed.add_field(\"Field 1\", \"Value 1\")\n    iex> DiscordInteractions.Embed.add_field(embed, \"Field 2\", \"Value 2\")\n    %{fields: [%{name: \"Field 1\", value: \"Value 1\", inline: false}, %{name: \"Field 2\", value: \"Value 2\", inline: false}]}","ref":"DiscordInteractions.Embed.html#add_field/4-examples"},{"type":"function","title":"DiscordInteractions.Embed.author/5","doc":"Sets the author of an embed.","ref":"DiscordInteractions.Embed.html#author/5"},{"type":"function","title":"Parameters - DiscordInteractions.Embed.author/5","doc":"- `embed`: The embed to modify\n- `name`: Name of the author\n- `url`: Optional URL of the author\n- `icon_url`: Optional URL of the author icon\n- `proxy_icon_url`: Optional proxied URL of the author icon","ref":"DiscordInteractions.Embed.html#author/5-parameters"},{"type":"function","title":"Examples - DiscordInteractions.Embed.author/5","doc":"iex> embed = DiscordInteractions.Embed.new()\n    iex> DiscordInteractions.Embed.author(embed, \"John Doe\")\n    %{author: %{name: \"John Doe\"}}\n\n    iex> embed = DiscordInteractions.Embed.new()\n    iex> DiscordInteractions.Embed.author(embed, \"John Doe\", \"https://example.com\", \"https://example.com/icon.png\")\n    %{author: %{name: \"John Doe\", url: \"https://example.com\", icon_url: \"https://example.com/icon.png\"}}","ref":"DiscordInteractions.Embed.html#author/5-examples"},{"type":"function","title":"DiscordInteractions.Embed.color/2","doc":"Sets the color of an embed.","ref":"DiscordInteractions.Embed.html#color/2"},{"type":"function","title":"Parameters - DiscordInteractions.Embed.color/2","doc":"- `embed`: The embed to modify\n- `color`: The color as an integer or hex string","ref":"DiscordInteractions.Embed.html#color/2-parameters"},{"type":"function","title":"Examples - DiscordInteractions.Embed.color/2","doc":"iex> embed = DiscordInteractions.Embed.new()\n    iex> DiscordInteractions.Embed.color(embed, 0x00FF00)\n    %{color: 65280}\n\n    iex> embed = DiscordInteractions.Embed.new()\n    iex> DiscordInteractions.Embed.color(embed, \"#00FF00\")\n    %{color: 65280}","ref":"DiscordInteractions.Embed.html#color/2-examples"},{"type":"function","title":"DiscordInteractions.Embed.description/2","doc":"Sets the description of an embed.","ref":"DiscordInteractions.Embed.html#description/2"},{"type":"function","title":"Parameters - DiscordInteractions.Embed.description/2","doc":"- `embed`: The embed to modify\n- `description`: The description text (up to 4096 characters)","ref":"DiscordInteractions.Embed.html#description/2-parameters"},{"type":"function","title":"Examples - DiscordInteractions.Embed.description/2","doc":"iex> embed = DiscordInteractions.Embed.new()\n    iex> DiscordInteractions.Embed.description(embed, \"This is a description\")\n    %{description: \"This is a description\"}","ref":"DiscordInteractions.Embed.html#description/2-examples"},{"type":"function","title":"DiscordInteractions.Embed.footer/4","doc":"Sets the footer of an embed.","ref":"DiscordInteractions.Embed.html#footer/4"},{"type":"function","title":"Parameters - DiscordInteractions.Embed.footer/4","doc":"- `embed`: The embed to modify\n- `text`: The footer text (up to 2048 characters)\n- `icon_url`: Optional URL of the footer icon\n- `proxy_icon_url`: Optional proxied URL of the footer icon","ref":"DiscordInteractions.Embed.html#footer/4-parameters"},{"type":"function","title":"Examples - DiscordInteractions.Embed.footer/4","doc":"iex> embed = DiscordInteractions.Embed.new()\n    iex> DiscordInteractions.Embed.footer(embed, \"Footer text\")\n    %{footer: %{text: \"Footer text\"}}\n\n    iex> embed = DiscordInteractions.Embed.new()\n    iex> DiscordInteractions.Embed.footer(embed, \"Footer text\", \"https://example.com/icon.png\")\n    %{footer: %{text: \"Footer text\", icon_url: \"https://example.com/icon.png\"}}","ref":"DiscordInteractions.Embed.html#footer/4-examples"},{"type":"function","title":"DiscordInteractions.Embed.image/3","doc":"Sets the image of an embed.","ref":"DiscordInteractions.Embed.html#image/3"},{"type":"function","title":"Parameters - DiscordInteractions.Embed.image/3","doc":"- `embed`: The embed to modify\n- `url`: URL of the image\n- `opts`: Optional parameters (proxy_url, height, width)","ref":"DiscordInteractions.Embed.html#image/3-parameters"},{"type":"function","title":"Examples - DiscordInteractions.Embed.image/3","doc":"iex> embed = DiscordInteractions.Embed.new()\n    iex> DiscordInteractions.Embed.image(embed, \"https://example.com/image.png\")\n    %{image: %{url: \"https://example.com/image.png\"}}\n\n    iex> embed = DiscordInteractions.Embed.new()\n    iex> DiscordInteractions.Embed.image(embed, \"https://example.com/image.png\", proxy_url: \"https://proxy.example.com/image.png\", height: 300, width: 400)\n    %{image: %{url: \"https://example.com/image.png\", proxy_url: \"https://proxy.example.com/image.png\", height: 300, width: 400}}","ref":"DiscordInteractions.Embed.html#image/3-examples"},{"type":"function","title":"DiscordInteractions.Embed.new/1","doc":"Creates a new empty embed object.","ref":"DiscordInteractions.Embed.html#new/1"},{"type":"function","title":"Examples - DiscordInteractions.Embed.new/1","doc":"iex> DiscordInteractions.Embed.new()\n    %{}\n\n    iex> DiscordInteractions.Embed.new(title: \"Hello\", description: \"World\")\n    %{title: \"Hello\", description: \"World\"}","ref":"DiscordInteractions.Embed.html#new/1-examples"},{"type":"function","title":"DiscordInteractions.Embed.provider/3","doc":"Sets the provider of an embed.","ref":"DiscordInteractions.Embed.html#provider/3"},{"type":"function","title":"Parameters - DiscordInteractions.Embed.provider/3","doc":"- `embed`: The embed to modify\n- `name`: Name of the provider\n- `url`: URL of the provider","ref":"DiscordInteractions.Embed.html#provider/3-parameters"},{"type":"function","title":"Examples - DiscordInteractions.Embed.provider/3","doc":"iex> embed = DiscordInteractions.Embed.new()\n    iex> DiscordInteractions.Embed.provider(embed, \"Example Provider\")\n    %{provider: %{name: \"Example Provider\"}}\n\n    iex> embed = DiscordInteractions.Embed.new()\n    iex> DiscordInteractions.Embed.provider(embed, \"Example Provider\", \"https://example.com\")\n    %{provider: %{name: \"Example Provider\", url: \"https://example.com\"}}","ref":"DiscordInteractions.Embed.html#provider/3-examples"},{"type":"type","title":"DiscordInteractions.Embed.t/0","doc":"","ref":"DiscordInteractions.Embed.html#t:t/0"},{"type":"function","title":"DiscordInteractions.Embed.thumbnail/3","doc":"Sets the thumbnail of an embed.","ref":"DiscordInteractions.Embed.html#thumbnail/3"},{"type":"function","title":"Parameters - DiscordInteractions.Embed.thumbnail/3","doc":"- `embed`: The embed to modify\n- `url`: URL of the thumbnail\n- `opts`: Optional parameters (proxy_url, height, width)","ref":"DiscordInteractions.Embed.html#thumbnail/3-parameters"},{"type":"function","title":"Examples - DiscordInteractions.Embed.thumbnail/3","doc":"iex> embed = DiscordInteractions.Embed.new()\n    iex> DiscordInteractions.Embed.thumbnail(embed, \"https://example.com/thumbnail.png\")\n    %{thumbnail: %{url: \"https://example.com/thumbnail.png\"}}\n\n    iex> embed = DiscordInteractions.Embed.new()\n    iex> DiscordInteractions.Embed.thumbnail(embed, \"https://example.com/thumbnail.png\", proxy_url: \"https://proxy.example.com/thumbnail.png\", height: 100, width: 100)\n    %{thumbnail: %{url: \"https://example.com/thumbnail.png\", proxy_url: \"https://proxy.example.com/thumbnail.png\", height: 100, width: 100}}","ref":"DiscordInteractions.Embed.html#thumbnail/3-examples"},{"type":"function","title":"DiscordInteractions.Embed.timestamp/2","doc":"Sets the timestamp of an embed.","ref":"DiscordInteractions.Embed.html#timestamp/2"},{"type":"function","title":"Parameters - DiscordInteractions.Embed.timestamp/2","doc":"- `embed`: The embed to modify\n- `timestamp`: The timestamp as a DateTime or ISO8601 string","ref":"DiscordInteractions.Embed.html#timestamp/2-parameters"},{"type":"function","title":"Examples - DiscordInteractions.Embed.timestamp/2","doc":"iex> embed = DiscordInteractions.Embed.new()\n    iex> DiscordInteractions.Embed.timestamp(embed, \"2023-01-01T12:00:00Z\")\n    %{timestamp: \"2023-01-01T12:00:00Z\"}\n\n    iex> embed = DiscordInteractions.Embed.new()\n    iex> timestamp = DateTime.from_naive!(~N[2023-01-01 12:00:00], \"Etc/UTC\")\n    iex> DiscordInteractions.Embed.timestamp(embed, timestamp)\n    %{timestamp: \"2023-01-01T12:00:00Z\"}","ref":"DiscordInteractions.Embed.html#timestamp/2-examples"},{"type":"function","title":"DiscordInteractions.Embed.title/2","doc":"Sets the title of an embed.","ref":"DiscordInteractions.Embed.html#title/2"},{"type":"function","title":"Parameters - DiscordInteractions.Embed.title/2","doc":"- `embed`: The embed to modify\n- `title`: The title text (up to 256 characters)","ref":"DiscordInteractions.Embed.html#title/2-parameters"},{"type":"function","title":"Examples - DiscordInteractions.Embed.title/2","doc":"iex> embed = DiscordInteractions.Embed.new()\n    iex> DiscordInteractions.Embed.title(embed, \"Hello, World!\")\n    %{title: \"Hello, World!\"}","ref":"DiscordInteractions.Embed.html#title/2-examples"},{"type":"function","title":"DiscordInteractions.Embed.url/2","doc":"Sets the URL of an embed.","ref":"DiscordInteractions.Embed.html#url/2"},{"type":"function","title":"Parameters - DiscordInteractions.Embed.url/2","doc":"- `embed`: The embed to modify\n- `url`: The URL for the embed title to link to","ref":"DiscordInteractions.Embed.html#url/2-parameters"},{"type":"function","title":"Examples - DiscordInteractions.Embed.url/2","doc":"iex> embed = DiscordInteractions.Embed.new()\n    iex> DiscordInteractions.Embed.url(embed, \"https://example.com\")\n    %{url: \"https://example.com\"}","ref":"DiscordInteractions.Embed.html#url/2-examples"},{"type":"function","title":"DiscordInteractions.Embed.video/3","doc":"Sets the video of an embed.","ref":"DiscordInteractions.Embed.html#video/3"},{"type":"function","title":"Parameters - DiscordInteractions.Embed.video/3","doc":"- `embed`: The embed to modify\n- `url`: URL of the video\n- `opts`: Optional parameters (proxy_url, height, width)","ref":"DiscordInteractions.Embed.html#video/3-parameters"},{"type":"function","title":"Examples - DiscordInteractions.Embed.video/3","doc":"iex> embed = DiscordInteractions.Embed.new()\n    iex> DiscordInteractions.Embed.video(embed, \"https://example.com/video.mp4\")\n    %{video: %{url: \"https://example.com/video.mp4\"}}\n\n    iex> embed = DiscordInteractions.Embed.new()\n    iex> DiscordInteractions.Embed.video(embed, \"https://example.com/video.mp4\", height: 720, width: 1280)\n    %{video: %{url: \"https://example.com/video.mp4\", height: 720, width: 1280}}","ref":"DiscordInteractions.Embed.html#video/3-examples"},{"type":"module","title":"DiscordInteractions.InteractionResponse","doc":"Provides functions for creating and manipulating Discord interaction responses.\n\nThis module implements the Discord Interaction Response API as documented at:\nhttps://discord.com/developers/docs/interactions/receiving-and-responding\n\nIt includes functions for creating different types of responses (like messages, modals, etc.)\nand modifying their properties (content, embeds, flags, etc.).","ref":"DiscordInteractions.InteractionResponse.html"},{"type":"module","title":"Examples - DiscordInteractions.InteractionResponse","doc":"# Create a simple message response\n    response = DiscordInteractions.InteractionResponse.channel_message_with_source()\n               |> DiscordInteractions.InteractionResponse.content(\"Hello, world!\")\n\n    # Create an ephemeral message (only visible to the user who triggered the interaction)\n    response = DiscordInteractions.InteractionResponse.channel_message_with_source()\n               |> DiscordInteractions.InteractionResponse.content(\"This is a secret message\")\n               |> DiscordInteractions.InteractionResponse.ephemeral()\n\n    # Create a message with an embed\n    alias DiscordInteractions.Embed\n\n    embed = Embed.new()\n            |> Embed.title(\"Hello, World!\")\n            |> Embed.description(\"This is an embed description\")\n            |> Embed.color(0x00FF00)\n            |> Embed.add_field(\"Field 1\", \"Value 1\", true)\n            |> Embed.add_field(\"Field 2\", \"Value 2\", true)\n\n    response = DiscordInteractions.InteractionResponse.channel_message_with_source()\n               |> DiscordInteractions.InteractionResponse.embeds([embed])\n\n    # Create a modal response\n    response = DiscordInteractions.InteractionResponse.modal()\n               |> DiscordInteractions.InteractionResponse.title(\"My Modal\")\n               |> DiscordInteractions.InteractionResponse.custom_id(\"my_modal\")\n               |> DiscordInteractions.InteractionResponse.components([...])","ref":"DiscordInteractions.InteractionResponse.html#module-examples"},{"type":"function","title":"DiscordInteractions.InteractionResponse.allowed_mentions/2","doc":"Sets the allowed mentions for a message response.\n\nThis controls which mentions in the message will actually ping users, roles, or everyone.","ref":"DiscordInteractions.InteractionResponse.html#allowed_mentions/2"},{"type":"function","title":"Parameters - DiscordInteractions.InteractionResponse.allowed_mentions/2","doc":"- `response`: The interaction response to modify\n- `opts`: Options for allowed mentions\n  - `:parse`: Types of mentions to parse (`:roles`, `:users`, `:everyone`)\n  - `:roles`: Array of role IDs to mention\n  - `:users`: Array of user IDs to mention\n  - `:replied_user`: Whether to mention the user being replied to","ref":"DiscordInteractions.InteractionResponse.html#allowed_mentions/2-parameters"},{"type":"function","title":"Examples - DiscordInteractions.InteractionResponse.allowed_mentions/2","doc":"iex> response = DiscordInteractions.InteractionResponse.channel_message_with_source()\n    iex> DiscordInteractions.InteractionResponse.allowed_mentions(response, parse: [:users])\n    %{type: 4, data: %{allowed_mentions: %{parse: [:users], roles: [], users: [], replied_user: false}}}","ref":"DiscordInteractions.InteractionResponse.html#allowed_mentions/2-examples"},{"type":"function","title":"DiscordInteractions.InteractionResponse.application_command_autocomplete_result/1","doc":"Creates a response with autocomplete suggestions for application command options.\n\nThis is used when a user is typing in an autocomplete-enabled option field.\nDiscord will display these choices to the user as they type, allowing them to\nselect from the provided options.","ref":"DiscordInteractions.InteractionResponse.html#application_command_autocomplete_result/1"},{"type":"function","title":"Parameters - DiscordInteractions.InteractionResponse.application_command_autocomplete_result/1","doc":"- `data`: Can be one of:\n  - A list of choice objects (each with `name` and `value` keys)\n  - A map with a `choices` key containing a list of choice objects\n  - An empty list (default) to show no suggestions","ref":"DiscordInteractions.InteractionResponse.html#application_command_autocomplete_result/1-parameters"},{"type":"function","title":"Examples - DiscordInteractions.InteractionResponse.application_command_autocomplete_result/1","doc":"Using a list of choices directly:\n\n    iex> choices = [\n    ...>   %{name: \"Option 1\", value: \"opt1\"},\n    ...>   %{name: \"Option 2\", value: \"opt2\"}\n    ...> ]\n    iex> DiscordInteractions.InteractionResponse.application_command_autocomplete_result(choices)\n    %{type: 8, data: %{choices: [%{name: \"Option 1\", value: \"opt1\"}, %{name: \"Option 2\", value: \"opt2\"}]}}\n\nUsing a map with choices:\n\n    iex> choices = [\n    ...>   %{name: \"Option 1\", value: \"opt1\"},\n    ...>   %{name: \"Option 2\", value: \"opt2\"}\n    ...> ]\n    iex> DiscordInteractions.InteractionResponse.application_command_autocomplete_result(%{choices: choices})\n    %{type: 8, data: %{choices: [%{name: \"Option 1\", value: \"opt1\"}, %{name: \"Option 2\", value: \"opt2\"}]}}\n\nUsing the choice helper function:\n\n    iex> choices = [\n    ...>   DiscordInteractions.InteractionResponse.choice(\"Option 1\", \"opt1\"),\n    ...>   DiscordInteractions.InteractionResponse.choice(\"Option 2\", \"opt2\")\n    ...> ]\n    iex> DiscordInteractions.InteractionResponse.application_command_autocomplete_result(choices)\n    %{type: 8, data: %{choices: [%{name: \"Option 1\", value: \"opt1\"}, %{name: \"Option 2\", value: \"opt2\"}]}}","ref":"DiscordInteractions.InteractionResponse.html#application_command_autocomplete_result/1-examples"},{"type":"function","title":"DiscordInteractions.InteractionResponse.attachments/2","doc":"Sets the attachments for a message response.\n\nAttachments are files that are attached to the message.","ref":"DiscordInteractions.InteractionResponse.html#attachments/2"},{"type":"function","title":"Parameters - DiscordInteractions.InteractionResponse.attachments/2","doc":"- `response`: The interaction response to modify\n- `attachments`: Array of attachment objects","ref":"DiscordInteractions.InteractionResponse.html#attachments/2-parameters"},{"type":"function","title":"Examples - DiscordInteractions.InteractionResponse.attachments/2","doc":"iex> response = DiscordInteractions.InteractionResponse.channel_message_with_source()\n    iex> attachment = %{id: 1, filename: \"file.txt\", description: \"A text file\"}\n    iex> DiscordInteractions.InteractionResponse.attachments(response, [attachment])\n    %{type: 4, data: %{attachments: [%{id: 1, filename: \"file.txt\", description: \"A text file\"}]}}","ref":"DiscordInteractions.InteractionResponse.html#attachments/2-examples"},{"type":"type","title":"DiscordInteractions.InteractionResponse.autocomplete/0","doc":"Represents an autocomplete response with choices.","ref":"DiscordInteractions.InteractionResponse.html#t:autocomplete/0"},{"type":"type","title":"Fields - DiscordInteractions.InteractionResponse.autocomplete/0","doc":"- `choices`: Array of choice objects for autocomplete suggestions","ref":"DiscordInteractions.InteractionResponse.html#t:autocomplete/0-fields"},{"type":"function","title":"DiscordInteractions.InteractionResponse.channel_message_with_source/1","doc":"Creates a response that shows a message in the channel.\n\nThis is the most common response type for application commands and components.","ref":"DiscordInteractions.InteractionResponse.html#channel_message_with_source/1"},{"type":"function","title":"Parameters - DiscordInteractions.InteractionResponse.channel_message_with_source/1","doc":"- `data`: Optional message data (content, embeds, etc.)","ref":"DiscordInteractions.InteractionResponse.html#channel_message_with_source/1-parameters"},{"type":"function","title":"Examples - DiscordInteractions.InteractionResponse.channel_message_with_source/1","doc":"iex> DiscordInteractions.InteractionResponse.channel_message_with_source()\n    %{type: 4, data: %{}}\n\n    iex> DiscordInteractions.InteractionResponse.channel_message_with_source(%{content: \"Hello!\"})\n    %{type: 4, data: %{content: \"Hello!\"}}","ref":"DiscordInteractions.InteractionResponse.html#channel_message_with_source/1-examples"},{"type":"type","title":"DiscordInteractions.InteractionResponse.choice/0","doc":"Represents a choice for autocomplete suggestions.","ref":"DiscordInteractions.InteractionResponse.html#t:choice/0"},{"type":"type","title":"Fields - DiscordInteractions.InteractionResponse.choice/0","doc":"- `name`: The display name of the choice shown to users\n- `value`: The value of the choice sent to your application when selected\n- `name_localizations`: Optional map of localized names for different languages","ref":"DiscordInteractions.InteractionResponse.html#t:choice/0-fields"},{"type":"function","title":"DiscordInteractions.InteractionResponse.choice/2","doc":"Creates a choice object for autocomplete suggestions.\n\nThis helper function creates a properly formatted choice object that can be used\nin autocomplete responses.","ref":"DiscordInteractions.InteractionResponse.html#choice/2"},{"type":"function","title":"Parameters - DiscordInteractions.InteractionResponse.choice/2","doc":"- `name`: The display name of the choice shown to users\n- `value`: The value of the choice sent to your application when selected","ref":"DiscordInteractions.InteractionResponse.html#choice/2-parameters"},{"type":"function","title":"Examples - DiscordInteractions.InteractionResponse.choice/2","doc":"iex> DiscordInteractions.InteractionResponse.choice(\"Red\", \"red\")\n    %{name: \"Red\", value: \"red\"}\n\n    iex> choices = [\n    ...>   DiscordInteractions.InteractionResponse.choice(\"Red\", \"red\"),\n    ...>   DiscordInteractions.InteractionResponse.choice(\"Blue\", \"blue\")\n    ...> ]\n    iex> DiscordInteractions.InteractionResponse.application_command_autocomplete_result(choices)\n    %{type: 8, data: %{choices: [%{name: \"Red\", value: \"red\"}, %{name: \"Blue\", value: \"blue\"}]}}","ref":"DiscordInteractions.InteractionResponse.html#choice/2-examples"},{"type":"function","title":"DiscordInteractions.InteractionResponse.choice/3","doc":"Creates a choice object for autocomplete suggestions with localization support.\n\nThis helper function creates a properly formatted choice object that can be used\nin autocomplete responses, including localized names for different languages.","ref":"DiscordInteractions.InteractionResponse.html#choice/3"},{"type":"function","title":"Parameters - DiscordInteractions.InteractionResponse.choice/3","doc":"- `name`: The default display name of the choice shown to users\n- `name_localizations`: Map of localized names for different languages (locale code -> name)\n- `value`: The value of the choice sent to your application when selected","ref":"DiscordInteractions.InteractionResponse.html#choice/3-parameters"},{"type":"function","title":"Examples - DiscordInteractions.InteractionResponse.choice/3","doc":"iex> localizations = %{\"es-ES\" => \"Rojo\", \"fr\" => \"Rouge\"}\n    iex> DiscordInteractions.InteractionResponse.choice(\"Red\", \"red\", localizations)\n    %{name: \"Red\", value: \"red\", name_localizations: %{\"es-ES\" => \"Rojo\", \"fr\" => \"Rouge\"}}","ref":"DiscordInteractions.InteractionResponse.html#choice/3-examples"},{"type":"function","title":"DiscordInteractions.InteractionResponse.components/2","doc":"Sets the components for a message response.\n\nComponents are interactive elements like buttons and select menus.","ref":"DiscordInteractions.InteractionResponse.html#components/2"},{"type":"function","title":"Parameters - DiscordInteractions.InteractionResponse.components/2","doc":"- `response`: The interaction response to modify\n- `components`: Array of component objects","ref":"DiscordInteractions.InteractionResponse.html#components/2-parameters"},{"type":"function","title":"Examples - DiscordInteractions.InteractionResponse.components/2","doc":"iex> response = DiscordInteractions.InteractionResponse.channel_message_with_source()\n    iex> button = DiscordInteractions.Components.button(style: :primary, label: \"Click Me\", custom_id: \"btn1\")\n    iex> action_row = DiscordInteractions.Components.action_row(components: [button])\n    iex> DiscordInteractions.InteractionResponse.components(response, [action_row])\n    %{type: 4, data: %{components: [%{type: 1, components: [%{type: 2, style: 1, label: \"Click Me\", custom_id: \"btn1\"}]}]}}","ref":"DiscordInteractions.InteractionResponse.html#components/2-examples"},{"type":"function","title":"DiscordInteractions.InteractionResponse.content/2","doc":"Sets the content of a message response.\n\nThis is the main text content of the message.","ref":"DiscordInteractions.InteractionResponse.html#content/2"},{"type":"function","title":"Parameters - DiscordInteractions.InteractionResponse.content/2","doc":"- `response`: The interaction response to modify\n- `content`: The text content to set","ref":"DiscordInteractions.InteractionResponse.html#content/2-parameters"},{"type":"function","title":"Examples - DiscordInteractions.InteractionResponse.content/2","doc":"iex> response = DiscordInteractions.InteractionResponse.channel_message_with_source()\n    iex> DiscordInteractions.InteractionResponse.content(response, \"Hello, world!\")\n    %{type: 4, data: %{content: \"Hello, world!\"}}","ref":"DiscordInteractions.InteractionResponse.html#content/2-examples"},{"type":"function","title":"DiscordInteractions.InteractionResponse.custom_id/2","doc":"Sets the custom ID of a modal response.\n\nThe custom ID is a developer-defined identifier that will be included when\nthe modal is submitted, allowing you to identify which modal was used.","ref":"DiscordInteractions.InteractionResponse.html#custom_id/2"},{"type":"function","title":"Parameters - DiscordInteractions.InteractionResponse.custom_id/2","doc":"- `response`: The interaction response to modify\n- `custom_id`: The custom ID to set","ref":"DiscordInteractions.InteractionResponse.html#custom_id/2-parameters"},{"type":"function","title":"Examples - DiscordInteractions.InteractionResponse.custom_id/2","doc":"iex> response = DiscordInteractions.InteractionResponse.modal()\n    iex> DiscordInteractions.InteractionResponse.custom_id(response, \"my_form_id\")\n    %{type: 9, data: %{custom_id: \"my_form_id\"}}","ref":"DiscordInteractions.InteractionResponse.html#custom_id/2-examples"},{"type":"function","title":"DiscordInteractions.InteractionResponse.deferred_channel_message_with_source/1","doc":"Creates a response that acknowledges an interaction and shows a loading state.\n\nThis allows you to acknowledge the interaction immediately and then follow up\nwith a message later using the webhook URL.","ref":"DiscordInteractions.InteractionResponse.html#deferred_channel_message_with_source/1"},{"type":"function","title":"Parameters - DiscordInteractions.InteractionResponse.deferred_channel_message_with_source/1","doc":"- `data`: Optional message data (content, embeds, etc.)","ref":"DiscordInteractions.InteractionResponse.html#deferred_channel_message_with_source/1-parameters"},{"type":"function","title":"Examples - DiscordInteractions.InteractionResponse.deferred_channel_message_with_source/1","doc":"iex> DiscordInteractions.InteractionResponse.deferred_channel_message_with_source()\n    %{type: 5, data: %{}}","ref":"DiscordInteractions.InteractionResponse.html#deferred_channel_message_with_source/1-examples"},{"type":"function","title":"DiscordInteractions.InteractionResponse.deferred_update_message/1","doc":"Creates a response that acknowledges a component interaction with a loading state.\n\nThis is used for component interactions (like buttons) when you need time to process\nbefore updating the message.","ref":"DiscordInteractions.InteractionResponse.html#deferred_update_message/1"},{"type":"function","title":"Parameters - DiscordInteractions.InteractionResponse.deferred_update_message/1","doc":"- `data`: Optional message data (content, embeds, etc.)","ref":"DiscordInteractions.InteractionResponse.html#deferred_update_message/1-parameters"},{"type":"function","title":"Examples - DiscordInteractions.InteractionResponse.deferred_update_message/1","doc":"iex> DiscordInteractions.InteractionResponse.deferred_update_message()\n    %{type: 6, data: %{}}","ref":"DiscordInteractions.InteractionResponse.html#deferred_update_message/1-examples"},{"type":"function","title":"DiscordInteractions.InteractionResponse.embeds/2","doc":"Sets the embeds for a message response.\n\nEmbeds are rich content blocks that can contain formatted text, images, and more.\nUse the `DiscordInteractions.Embed` module to create embed objects.","ref":"DiscordInteractions.InteractionResponse.html#embeds/2"},{"type":"function","title":"Parameters - DiscordInteractions.InteractionResponse.embeds/2","doc":"- `response`: The interaction response to modify\n- `embeds`: Array of embed objects","ref":"DiscordInteractions.InteractionResponse.html#embeds/2-parameters"},{"type":"function","title":"Examples - DiscordInteractions.InteractionResponse.embeds/2","doc":"Using a simple map for the embed:\n\n    iex> response = DiscordInteractions.InteractionResponse.channel_message_with_source()\n    iex> embed = %{title: \"My Embed\", description: \"This is an embed\", color: 0x00FF00}\n    iex> DiscordInteractions.InteractionResponse.embeds(response, [embed])\n    %{type: 4, data: %{embeds: [%{title: \"My Embed\", description: \"This is an embed\", color: 0x00FF00}]}}\n\nUsing the Embed module (recommended):\n\n    iex> alias DiscordInteractions.Embed\n    iex> response = DiscordInteractions.InteractionResponse.channel_message_with_source()\n    iex> embed = Embed.new()\n    ...>         |> Embed.title(\"My Embed\")\n    ...>         |> Embed.description(\"This is an embed\")\n    ...>         |> Embed.color(0x00FF00)\n    iex> DiscordInteractions.InteractionResponse.embeds(response, [embed])\n    %{type: 4, data: %{embeds: [%{title: \"My Embed\", description: \"This is an embed\", color: 0x00FF00}]}}\n\nCreating a more complex embed:\n\n    iex> alias DiscordInteractions.Embed\n    iex> response = DiscordInteractions.InteractionResponse.channel_message_with_source()\n    iex> embed = Embed.new()\n    ...>         |> Embed.title(\"User Profile\")\n    ...>         |> Embed.description(\"User information\")\n    ...>         |> Embed.color(\"#5865F2\")\n    ...>         |> Embed.thumbnail(\"https://example.com/avatar.png\")\n    ...>         |> Embed.add_field(\"Username\", \"JohnDoe\", true)\n    ...>         |> Embed.add_field(\"Status\", \"Online\", true)\n    ...>         |> Embed.footer(\"Last updated\", \"https://example.com/icon.png\")\n    iex> DiscordInteractions.InteractionResponse.embeds(response, [embed])\n    %{type: 4, data: %{embeds: [%{title: \"User Profile\", description: \"User information\", color: 5793266, thumbnail: %{url: \"https://example.com/avatar.png\"}, fields: [%{name: \"Username\", value: \"JohnDoe\", inline: true}, %{name: \"Status\", value: \"Online\", inline: true}], footer: %{text: \"Last updated\", icon_url: \"https://example.com/icon.png\"}}]}}","ref":"DiscordInteractions.InteractionResponse.html#embeds/2-examples"},{"type":"function","title":"DiscordInteractions.InteractionResponse.ephemeral/1","doc":"Sets the ephemeral flag on a message response.\n\nWhen this flag is set, the message will only be visible to the user who\ntriggered the interaction and will disappear when the user refreshes or\nnavigates away.","ref":"DiscordInteractions.InteractionResponse.html#ephemeral/1"},{"type":"function","title":"Parameters - DiscordInteractions.InteractionResponse.ephemeral/1","doc":"- `response`: The interaction response to modify","ref":"DiscordInteractions.InteractionResponse.html#ephemeral/1-parameters"},{"type":"function","title":"Examples - DiscordInteractions.InteractionResponse.ephemeral/1","doc":"iex> response = DiscordInteractions.InteractionResponse.channel_message_with_source()\n    iex> DiscordInteractions.InteractionResponse.ephemeral(response)\n    %{type: 4, data: %{flags: 64}}\n\n    iex> response = DiscordInteractions.InteractionResponse.channel_message_with_source(%{flags: 2})\n    iex> DiscordInteractions.InteractionResponse.ephemeral(response)\n    %{type: 4, data: %{flags: 66}}","ref":"DiscordInteractions.InteractionResponse.html#ephemeral/1-examples"},{"type":"function","title":"DiscordInteractions.InteractionResponse.flags/2","doc":"Sets the flags for a message response.\n\nFlags control special behavior of the message, such as making it ephemeral.","ref":"DiscordInteractions.InteractionResponse.html#flags/2"},{"type":"function","title":"Parameters - DiscordInteractions.InteractionResponse.flags/2","doc":"- `response`: The interaction response to modify\n- `flags`: Integer value of the flags to set","ref":"DiscordInteractions.InteractionResponse.html#flags/2-parameters"},{"type":"function","title":"Examples - DiscordInteractions.InteractionResponse.flags/2","doc":"iex> response = DiscordInteractions.InteractionResponse.channel_message_with_source()\n    iex> DiscordInteractions.InteractionResponse.flags(response, 64) # Ephemeral flag\n    %{type: 4, data: %{flags: 64}}","ref":"DiscordInteractions.InteractionResponse.html#flags/2-examples"},{"type":"function","title":"DiscordInteractions.InteractionResponse.launch_activity/0","doc":"Creates a response that launches an activity.\n\nThis is used for launching Discord activities (like games).","ref":"DiscordInteractions.InteractionResponse.html#launch_activity/0"},{"type":"function","title":"Examples - DiscordInteractions.InteractionResponse.launch_activity/0","doc":"iex> DiscordInteractions.InteractionResponse.launch_activity()\n    %{type: 12}","ref":"DiscordInteractions.InteractionResponse.html#launch_activity/0-examples"},{"type":"type","title":"DiscordInteractions.InteractionResponse.message/0","doc":"Represents a message response with optional fields.","ref":"DiscordInteractions.InteractionResponse.html#t:message/0"},{"type":"type","title":"Fields - DiscordInteractions.InteractionResponse.message/0","doc":"- `tts`: Whether the message should be read aloud by Discord\n- `content`: The text content of the message\n- `embeds`: Array of embed objects\n- `allowed_mentions`: Controls which mentions are allowed in the message\n- `flags`: Message flags (like ephemeral, suppress_embeds, etc.)\n- `components`: Array of message components (buttons, select menus, etc.)\n- `attachments`: Array of attachment objects\n- `poll`: Poll object for creating polls","ref":"DiscordInteractions.InteractionResponse.html#t:message/0-fields"},{"type":"type","title":"DiscordInteractions.InteractionResponse.modal/0","doc":"Represents a modal response.","ref":"DiscordInteractions.InteractionResponse.html#t:modal/0"},{"type":"type","title":"Fields - DiscordInteractions.InteractionResponse.modal/0","doc":"- `title`: The title of the modal\n- `custom_id`: A developer-defined identifier for the modal\n- `components`: Array of components to include in the modal","ref":"DiscordInteractions.InteractionResponse.html#t:modal/0-fields"},{"type":"function","title":"DiscordInteractions.InteractionResponse.modal/1","doc":"Creates a response that shows a modal dialog.\n\nThis is used to prompt the user for additional input through a form.","ref":"DiscordInteractions.InteractionResponse.html#modal/1"},{"type":"function","title":"Parameters - DiscordInteractions.InteractionResponse.modal/1","doc":"- `data`: Modal data (title, custom_id, components)","ref":"DiscordInteractions.InteractionResponse.html#modal/1-parameters"},{"type":"function","title":"Examples - DiscordInteractions.InteractionResponse.modal/1","doc":"iex> modal_data = %{title: \"My Form\", custom_id: \"my_form\", components: []}\n    iex> DiscordInteractions.InteractionResponse.modal(modal_data)\n    %{type: 9, data: %{title: \"My Form\", custom_id: \"my_form\", components: []}}","ref":"DiscordInteractions.InteractionResponse.html#modal/1-examples"},{"type":"function","title":"DiscordInteractions.InteractionResponse.poll/2","doc":"Sets the poll for a message response.\n\nPolls allow users to vote on options.","ref":"DiscordInteractions.InteractionResponse.html#poll/2"},{"type":"function","title":"Parameters - DiscordInteractions.InteractionResponse.poll/2","doc":"- `response`: The interaction response to modify\n- `poll`: Poll object","ref":"DiscordInteractions.InteractionResponse.html#poll/2-parameters"},{"type":"function","title":"Examples - DiscordInteractions.InteractionResponse.poll/2","doc":"iex> response = DiscordInteractions.InteractionResponse.channel_message_with_source()\n    iex> poll = %{question: \"Favorite color?\", options: [%{text: \"Red\"}, %{text: \"Blue\"}]}\n    iex> DiscordInteractions.InteractionResponse.poll(response, poll)\n    %{type: 4, data: %{poll: %{question: \"Favorite color?\", options: [%{text: \"Red\"}, %{text: \"Blue\"}]}}}","ref":"DiscordInteractions.InteractionResponse.html#poll/2-examples"},{"type":"function","title":"DiscordInteractions.InteractionResponse.pong/0","doc":"Creates a Pong response to acknowledge a Ping interaction.\n\nThis is used to respond to Discord's ping requests to verify that your\ninteraction endpoint is working.","ref":"DiscordInteractions.InteractionResponse.html#pong/0"},{"type":"function","title":"Examples - DiscordInteractions.InteractionResponse.pong/0","doc":"iex> DiscordInteractions.InteractionResponse.pong()\n    %{type: 1}","ref":"DiscordInteractions.InteractionResponse.html#pong/0-examples"},{"type":"function","title":"DiscordInteractions.InteractionResponse.premium_required/0","doc":"Creates a response indicating that a premium subscription is required.\n\nThis is used for premium-only features.","ref":"DiscordInteractions.InteractionResponse.html#premium_required/0"},{"type":"function","title":"Examples - DiscordInteractions.InteractionResponse.premium_required/0","doc":"iex> DiscordInteractions.InteractionResponse.premium_required()\n    %{type: 10}","ref":"DiscordInteractions.InteractionResponse.html#premium_required/0-examples"},{"type":"function","title":"DiscordInteractions.InteractionResponse.suppress_embeds/1","doc":"Sets the suppress embeds flag on a message response.\n\nWhen this flag is set, Discord will not display any embeds in the message.","ref":"DiscordInteractions.InteractionResponse.html#suppress_embeds/1"},{"type":"function","title":"Parameters - DiscordInteractions.InteractionResponse.suppress_embeds/1","doc":"- `response`: The interaction response to modify","ref":"DiscordInteractions.InteractionResponse.html#suppress_embeds/1-parameters"},{"type":"function","title":"Examples - DiscordInteractions.InteractionResponse.suppress_embeds/1","doc":"iex> response = DiscordInteractions.InteractionResponse.channel_message_with_source()\n    iex> DiscordInteractions.InteractionResponse.suppress_embeds(response)\n    %{type: 4, data: %{flags: 2}}\n\n    iex> response = DiscordInteractions.InteractionResponse.channel_message_with_source(%{flags: 64})\n    iex> DiscordInteractions.InteractionResponse.suppress_embeds(response)\n    %{type: 4, data: %{flags: 66}}","ref":"DiscordInteractions.InteractionResponse.html#suppress_embeds/1-examples"},{"type":"function","title":"DiscordInteractions.InteractionResponse.suppress_notifications/1","doc":"Sets the suppress notifications flag on a message response.\n\nWhen this flag is set, the message will not trigger push or desktop notifications.","ref":"DiscordInteractions.InteractionResponse.html#suppress_notifications/1"},{"type":"function","title":"Parameters - DiscordInteractions.InteractionResponse.suppress_notifications/1","doc":"- `response`: The interaction response to modify","ref":"DiscordInteractions.InteractionResponse.html#suppress_notifications/1-parameters"},{"type":"function","title":"Examples - DiscordInteractions.InteractionResponse.suppress_notifications/1","doc":"iex> response = DiscordInteractions.InteractionResponse.channel_message_with_source()\n    iex> DiscordInteractions.InteractionResponse.suppress_notifications(response)\n    %{type: 4, data: %{flags: 4096}}\n\n    iex> response = DiscordInteractions.InteractionResponse.channel_message_with_source(%{flags: 64})\n    iex> DiscordInteractions.InteractionResponse.suppress_notifications(response)\n    %{type: 4, data: %{flags: 4160}}","ref":"DiscordInteractions.InteractionResponse.html#suppress_notifications/1-examples"},{"type":"type","title":"DiscordInteractions.InteractionResponse.t/0","doc":"Represents a complete interaction response.","ref":"DiscordInteractions.InteractionResponse.html#t:t/0"},{"type":"type","title":"Fields - DiscordInteractions.InteractionResponse.t/0","doc":"- `type`: The type of response (numeric value)\n- `data`: The data for the response, which varies based on the type","ref":"DiscordInteractions.InteractionResponse.html#t:t/0-fields"},{"type":"function","title":"DiscordInteractions.InteractionResponse.title/2","doc":"Sets the title of a modal response.\n\nThe title appears at the top of the modal dialog.","ref":"DiscordInteractions.InteractionResponse.html#title/2"},{"type":"function","title":"Parameters - DiscordInteractions.InteractionResponse.title/2","doc":"- `response`: The interaction response to modify\n- `title`: The title text to set","ref":"DiscordInteractions.InteractionResponse.html#title/2-parameters"},{"type":"function","title":"Examples - DiscordInteractions.InteractionResponse.title/2","doc":"iex> response = DiscordInteractions.InteractionResponse.modal()\n    iex> DiscordInteractions.InteractionResponse.title(response, \"My Form\")\n    %{type: 9, data: %{title: \"My Form\"}}","ref":"DiscordInteractions.InteractionResponse.html#title/2-examples"},{"type":"function","title":"DiscordInteractions.InteractionResponse.tts/1","doc":"Sets the Text-to-Speech flag on a message response.\n\nWhen this flag is set, Discord will read the message aloud in the channel\nusing text-to-speech.","ref":"DiscordInteractions.InteractionResponse.html#tts/1"},{"type":"function","title":"Parameters - DiscordInteractions.InteractionResponse.tts/1","doc":"- `response`: The interaction response to modify","ref":"DiscordInteractions.InteractionResponse.html#tts/1-parameters"},{"type":"function","title":"Examples - DiscordInteractions.InteractionResponse.tts/1","doc":"iex> response = DiscordInteractions.InteractionResponse.channel_message_with_source()\n    iex> DiscordInteractions.InteractionResponse.tts(response)\n    %{type: 4, data: %{tts: true}}","ref":"DiscordInteractions.InteractionResponse.html#tts/1-examples"},{"type":"function","title":"DiscordInteractions.InteractionResponse.update_message/1","doc":"Creates a response that updates the message a component was attached to.\n\nThis is used for component interactions (like buttons) to update the original message.","ref":"DiscordInteractions.InteractionResponse.html#update_message/1"},{"type":"function","title":"Parameters - DiscordInteractions.InteractionResponse.update_message/1","doc":"- `data`: Optional message data (content, embeds, etc.)","ref":"DiscordInteractions.InteractionResponse.html#update_message/1-parameters"},{"type":"function","title":"Examples - DiscordInteractions.InteractionResponse.update_message/1","doc":"iex> DiscordInteractions.InteractionResponse.update_message(%{content: \"Updated content\"})\n    %{type: 7, data: %{content: \"Updated content\"}}","ref":"DiscordInteractions.InteractionResponse.html#update_message/1-examples"},{"type":"function","title":"DiscordInteractions.InteractionResponse.use_components_v2/1","doc":"Sets the components v2 flag on a message response.\n\nWhen this flag is set, it allows you to create fully component-driven messages\nwith the new Discord UI components system.","ref":"DiscordInteractions.InteractionResponse.html#use_components_v2/1"},{"type":"function","title":"Parameters - DiscordInteractions.InteractionResponse.use_components_v2/1","doc":"- `response`: The interaction response to modify","ref":"DiscordInteractions.InteractionResponse.html#use_components_v2/1-parameters"},{"type":"function","title":"Examples - DiscordInteractions.InteractionResponse.use_components_v2/1","doc":"iex> response = DiscordInteractions.InteractionResponse.channel_message_with_source()\n    iex> DiscordInteractions.InteractionResponse.use_components_v2(response)\n    %{type: 4, data: %{flags: 32768}}\n\n    iex> response = DiscordInteractions.InteractionResponse.channel_message_with_source(%{flags: 64})\n    iex> DiscordInteractions.InteractionResponse.use_components_v2(response)\n    %{type: 4, data: %{flags: 32832}}","ref":"DiscordInteractions.InteractionResponse.html#use_components_v2/1-examples"},{"type":"module","title":"DiscordInteractions.Plug","doc":"A Plug for handling Discord interaction webhooks.\n\nThis plug serves as the entry point for Discord interaction requests and implements\nthe complete [Discord Interactions API](https://discord.com/developers/docs/interactions/receiving-and-responding)\nwebhook flow, including:\n\n1. Verifying security headers using Ed25519 signatures\n2. Handling ping interactions automatically\n3. Routing command, component, and modal interactions to your handler functions","ref":"DiscordInteractions.Plug.html"},{"type":"module","title":"Usage - DiscordInteractions.Plug","doc":"Add this plug to your Phoenix router to handle Discord interaction webhooks:\n\n```elixir\n# In your router.ex file\ndefmodule YourAppWeb.Router do\n  use YourAppWeb, :router\n\n  # Other routes...\n\n  # Route for Discord interactions\n  forward \"/discord\", DiscordInteractions.Plug, YourApp.Discord\nend\n```\n\nWhere `YourApp.Discord` is a module that uses `DiscordInteractions` and defines\nyour interaction handlers.","ref":"DiscordInteractions.Plug.html#module-usage"},{"type":"function","title":"DiscordInteractions.Plug.call/2","doc":"Callback implementation for  Plug.call/2 .","ref":"DiscordInteractions.Plug.html#call/2"},{"type":"function","title":"DiscordInteractions.Plug.init/1","doc":"Callback implementation for  Plug.init/1 .","ref":"DiscordInteractions.Plug.html#init/1"},{"type":"module","title":"DiscordInteractions.Plug.HandleRequest","doc":"Handles Discord interaction requests after validation.","ref":"DiscordInteractions.Plug.HandleRequest.html"},{"type":"module","title":"DiscordInteractions.Plug.ValidateRequest","doc":"Validates security headers in Discord interaction requests.","ref":"DiscordInteractions.Plug.ValidateRequest.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.1"}}